OC.L10N.register(
    "spreed",
    {
    "a conversation" : "konverzácia",
    "(Duration %s)" : "(Trvanie %s)",
    "You attended a call with {user1}" : "Zúčastnili ste sa hovoru s {user1}",
    "_%n guest_::_%n guests_" : ["%n hosť","%n hostí","%n hostí","%n hostí"],
    "You attended a call with {user1} and {user2}" : "Zúčastnili ste sa hovoru s {user1} a {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Zúčastnili ste sa hovoru s {user1}, {user2} a {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Zúčastnili ste sa hovoru s {user1}, {user2}, {user3} a {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Zúčastnili ste sa hovoru s {user1}, {user2}, {user3}, {user4} a {user5}",
    "_%n other_::_%n others_" : ["%n ďalší","%n ďalší","%n ďalších","%niní"],
    "{actor} invited you to {call}" : "{actor} Vás pozval na {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Boli ste pozvaní na <strong>rozhovor</strong> alebo vám niekto <strong>volal</strong>",
    "Other activities" : "Iné aktivity",
    "Talk" : "Talk /Rozhovor/",
    "Guest" : "Hosť",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Vitajte v Nextcloud Talk /Rozhovore/!\nV tejto konverzácii vás budeme informovať o nových funkciách, ktoré sú dostupné v aplikácii Nextcloud Talk /Rozhovor/.",
    "## New in Talk %s" : "## Novinky v Talk /Rozhovore/ 1%s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge a Safari sa teraz môžu využívať na audio a video hovory",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Rozhovory typu jeden na jedného sú teraz trvalé a už ich nemožno náhodou zmeniť na skupinové rozhovory. Keď jeden z účastníkov opustí rozhovor, tento sa už automaticky neodstráni. Rozhovor sa odstráni zo servera, iba ak ho opustia obaja účastníci",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Teraz môžete upozorniť všetkých účastníkov uverejnením „@all“ do četu",
    "- With the \"arrow-up\" key you can repost your last message" : "- Pomocou tlačidla „šípka nahor“ môžete znova odoslať svoju poslednú správu",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Aplikácia Talk /Rozhovor/ teraz disponuje príkazmi pre aplikáciu. To, či správca vášho Nextcloud nejaké nastavil, zistíte zaslaním správy s textom „/ help“",
    "- With projects you can create quick links between conversations, files and other items" : "- Pomocou projektov môžete vytvárať prepojenia medzi konverzáciami, súbormi a inými položkami",
    "- You can now mention guests in the chat" : "- Teraz môžete v rozhovore „spomenúť“ hostí",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Konverzácie teraz môžu mať čakáreň. To umožní moderátorom pripojiť sa k četu alebo rozhovoru s predstihom na prípravu schôdzky, zatiaľ čo ostatní používatelia a hostia čakajú",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Teraz môžete odpovedať na správy priamo a poskytnúť tak ostatným predstavu o kontexte vašej správy",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Vyhľadávanie v rozhovoroch a účastníkoch teraz odfiltruje aj vaše existujúce rozhovory, čím sa oveľa ľahšie nájdu predchádzajúce rozhovory",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Po nainštalovaní aplikácie Kruhy môžete do konverzácií pridať vlastné skupiny používateľov",
    "- Check out the new grid and call view" : "- Vyskúšajte nové zobrazenie v mriežke a hovorov",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Teraz môžete nahrávať a presúvať súbory priamo z vášho zariadenia do četu",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Zdieľané súbory sa teraz otvárajú priamo v zobrazení četu pomocou aplikácií prehliadača",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Teraz môžete hľadať čety a správy v zjednotenom vyhľadávaní v hornej lište",
    "- Spice up your messages with emojis from the emoji picker" : "- Okoreňte svoje správy emotikonami vďaka dialógu na ich výber",
    "- You can now change your camera and microphone while being in a call" : "- Počas hovoru môžete teraz zmeniť kameru a mikrofón",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Poskytnite svojim konverzáciám určitý kontext s popisom a otvorte ich, aby ich prihlásení používatelia mohli nájsť a pripojiť sa",
    "- See a read status and send failed messages again" : "- Uvidíte stav načítania a znova pošlete správy, ktoré zlyhali",
    "- Raise your hand in a call with the R key" : "- zdvihnite ruku v hovore pomocou klávesy R",
    "- Join the same conversation and call from multiple devices" : "- Pripojte sa k tej istej konverzácii a telefonujte z viacerých zariadení",
    "- Send voice messages, share your location or contact details" : "- Posielajte hlasové správy, zdieľajte svoju polohu alebo kontaktné údaje",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Pridajte skupiny do konverzácie a noví členovia skupiny sa automaticky pridajú ako účastníci",
    "- A preview of your audio and video is shown before joining a call" : "- Pred pripojením k hovoru sa zobrazí ukážka vášho zvuku a videa",
    "- You can now blur your background in the newly designed call view" : "- Teraz môžete rozmazať pozadie v novom zobrazení hovoru",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderátori môžu teraz prideľovať účastníkom všeobecné a individuálne práva",
    "- You can now react to chat messages" : "- Teraz môžete reagovať na správu v čete",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Na bočnom paneli teraz nájdete prehľad najnovších zdieľaných položiek",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Použite anketu na zhromaždenie názorov ostatných alebo sa dohodnite na rande",
    "- Configure an expiration time for chat messages" : "- Nakonfigurujte čas vypršania platnosti četových správ",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Začnite hovory bez upozorňovania ostatných vo veľkých rozhovoroch. Po začatí hovoru môžete odosielať upozornenia individuálne.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Posielajte četové správy bez upozornenia príjemcov v prípade, že to nie je naliehavé",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emotikony môžu byť automaticky doplnené napísaním \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Prepojte rôzne položky pomocou nového inteligentného vyberania tým, že napíšete \"/\".",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderátori odteraz môžu vytvoriť oddelené miestnosti (vyžaduje vysokovýkonný backend)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Hovory môžu byť odteraz zaznamenané (vyžaduje vysokovýkonný backend)",
    "- Conversations can now have an avatar or emoji as icon" : "- Konverzácie môžu teraz mať ako ikonu avatara alebo emotikon.",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Virtuálne pozadia sú teraz dostupné spolu s rozmazaným pozadím pri videohovoroch.",
    "- Reactions are now available during calls" : "- Reakcie sú teraz dostupné počas hovorov",
    "- Typing indicators show which users are currently typing a message" : "- Indikátory písania ukazujú, ktorí užívatelia práve píšu správu",
    "- Groups can now be mentioned in chats" : "- Skupiny môžu teraz byť spomínané v chatoch",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Hovory sú automaticky prepisované na text, ak je zaregistrovaná aplikácia poskytujúca prepisovanie na text",
    "- Chat messages can be translated if a translation provider app is registered" : "- Chatovacie správy môžu byť preložené, ak je zaregistrovaná aplikácia pre poskytovanie prekladov",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** je teraz možné používať v _chatovacích_ správach",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooky sú teraz k dispozícii na implementáciu botov. Viac informácií nájdete v dokumentácii https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Nastavte si pripomienku na správu v chate, aby ste boli neskôr znovu upozornení",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Použite konverzáciu **Poznámka pre seba**, aby ste si robili poznámky a sprístupňovali informácie medzi vašimi zariadeniami",
    "- Captions allow to send a message with a file at the same time" : "- Titulky umožňujú súčasne odoslať správu so súborom",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video rečníka je teraz viditeľné pri sprístupňovaní obrazovky a reakcie na hovor sú animované",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Správy teraz môžu upravovať prihlásení autori a moderátori po dobu 6 hodín",
    "- Unsent message drafts are now saved in your browser" : "- Koncepty neodoslaných správ sú odteraz uložené vo vašom prehliadači",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Textové chatovanie je odteraz možné vykonávať federatívnym spôsobom s inými servermi Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderátori môžu zakázať účty a hostí, aby im zabránili znovu sa pripojiť ku konverzácii",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Nadchádzajúce hovory z prepojených udalostí v kalendári a náhrada za kolegu mimo kancelárie sa teraz zobrazujú v konverzáciách",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Hovory je teraz možné uskutočňovať federatívnym spôsobom s inými servermi Talk (vyžaduje vysokovýkonný backend)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Predstavujeme desktopového klienta Nextcloud Talk pre Windows, MacOS a Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Zhrnutie nahrávok hovorov a neprečítaných správ v rozhovoroch pomocou asistenta Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Vylepšené stretnutia s rozpoznávaním hostí pozvaných prostredníctvom ich e-mailovej adresy, import zoznamov účastníkov, koncepty pre prieskumy a sťahovanie zoznamov účastníkov hovorov",
    "- Archive conversations to stay focused" : "- Archivujte konverzácie, aby ste sa mohli sústrediť",
    "- Schedule a meeting into your calendar from within a conversation" : "- Naplánujte si stretnutie do kalendára priamo z konverzácie",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Vyhľadajte správy aktuálnej konverzácie priamo v pravom bočnom paneli",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Na prvý pohľad uvidíte viac konverzácií s novým kompaktným zoznamom (Nutné povoliť v nastaveniach Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Konverzácie v schôdzkach teraz synchronizujú názov a popis z kalendára a sú skryté pomocou filtra vyhľadávania, kým sa nezačnú blížiť k začiatku",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Označiť konverzácie ako citlivé v nastaveniach notifikácií, aby sa skryl obsah správy zo zoznamu konverzácií a notifikácií",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Aby ste dostávali push notifikácie počas režimu \"Nerušiť\", označte konverzácie ako dôležité",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Pridajte ďalších účastníkov do hovorov jeden na jedného a vytvorte nový skupinový hovor na mieste",
    "- Use threads to keep your chat and discussions organized" : "- Použite vlákna na udržanie poriadku vo vašich chatoch a diskusiách",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Živé prepisy sú teraz k dispozícii počas hovoru (vyžaduje aplikáciu ExApp pre živý prepis a vysoko výkonný backend)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderátori teraz môžu pripnúť správy, aby zostali na vrchu.",
    "- Schedule a message to send it at a later time" : "- Naplánovať správu na odoslanie neskôr.",
    "_All %n participant_::_All %n participants_" : ["%n účastník","Všetci %n účastníci","Všetkých %n účastníkov","Všetkých %n účastníkov"],
    "Talk updates ✅" : "Aktualizácie Talk /Rozhovor/ ✅",
    "Reaction deleted by author" : "Reakcia bola vymazaná autorom",
    "{actor} created the conversation" : "Používateľ {actor} vytvoril rozhovor",
    "You created the conversation" : "Vytvorili ste konverzáciu",
    "System created the conversation" : "Systém vytvoril konverzáciu",
    "An administrator created the conversation" : "Administrátor vytvoril rozhovor.",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "Používateľ {actor} premenoval rozhovor z \"%1$s\" na \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Premenovali ste rozhovor z \"%1$s\" na \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administrátor premenoval rozhovor z „%1$s“ na „%2$s“.",
    "{actor} set the description" : "{actor} nastavil popis",
    "You set the description" : "Nastavili ste popis",
    "An administrator set the description" : "Administrátor nastavil popis",
    "{actor} removed the description" : "{actor} odstránil popis",
    "You removed the description" : "Odstránili ste popis",
    "An administrator removed the description" : "Administrátor odstránil popis",
    "You started a silent call" : "Začali ste tichý rozhovor",
    "Outgoing silent call" : "Odchodzí hovor bez vyzváňania",
    "{actor} started a silent call" : "{actor} začal tichý rozhovor",
    "Incoming silent call" : "Príchodzí hovor bez vyzváňania",
    "You started a call" : "Začali ste hovor",
    "Outgoing call" : "Odchodzí hovor",
    "{actor} started a call" : "{actor} začal hovor",
    "Incoming call" : "Prichádzajúci hovor",
    "{actor} joined the call" : "{actor} sa pripojil k hovoru",
    "You joined the call" : "Pridali ste sa k hovoru",
    "{actor} left the call" : "{actor} odišiel z hovoru",
    "You left the call" : "Odišli ste z hovoru",
    "{actor} unlocked the conversation" : "{actor} odomkol rozhovor",
    "You unlocked the conversation" : "Odomkli ste rozhovor",
    "An administrator unlocked the conversation" : "Administrátor odomkol rozhovor",
    "{actor} locked the conversation" : "{actor} zamkol rozhovor",
    "You locked the conversation" : "Uzamkli ste rozhovor",
    "An administrator locked the conversation" : "Administrátor zamkol rozhovor",
    "{actor} limited the conversation to the current participants" : "{actor} obmedzil konverzáciu na aktuálnych účastníkov",
    "You limited the conversation to the current participants" : "Konverzáciu ste obmedzili na aktuálnych účastníkov",
    "An administrator limited the conversation to the current participants" : "Administrátor obmedzil konverzáciu na aktuálnych účastníkov",
    "{actor} opened the conversation to registered users" : "{actor} otvoril rozhovor registrovaným užívateľom",
    "You opened the conversation to registered users" : "Otvorili ste rozhovor registrovaným užívateľom",
    "An administrator opened the conversation to registered users" : "Administrátor otvoril rozhovor registrovaným užívateľom",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} otvoril konverzáciu pre registrovaných užívateľov a užívateľov vytvorených pomocou aplikácie Guests",
    "You opened the conversation to registered users and users created with the Guests app" : "Otvorili ste konverzáciu pre registrovaných užívateľov a užívateľov vytvorených pomocou aplikácie Guests",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Administrátor otvoril konverzáciu pre registrovaných užívateľov a užívateľov vytvorených pomocou aplikácie Guests",
    "The conversation is now open to everyone" : "Rozhovor je teraz otvorený pre každého",
    "{actor} opened the conversation to everyone" : "{actor} otvoril rozhovor všetkým",
    "You opened the conversation to everyone" : "Rozhovor ste otvorili všetkým",
    "{actor} restricted the conversation to moderators" : "{actor} obmedzil rozhovor na moderátorov",
    "You restricted the conversation to moderators" : "Rozhovor ste obmedzili na moderátorov",
    "{actor} started breakout rooms" : "{actor} spustil vyhradené miestnosti",
    "You started breakout rooms" : "Otvorili ste vyhradené miestnosti",
    "{actor} stopped breakout rooms" : "{actor} zastavil(a) vyhradené miestnosti",
    "You stopped breakout rooms" : "Uzatvorili ste vyhradené miestnosti",
    "{actor} allowed guests" : "{actor} povolil hostí",
    "You allowed guests" : "Povolili ste hostí",
    "An administrator allowed guests" : "Administrátor povolil hostí",
    "{actor} disallowed guests" : "{actor} zákazal hostí",
    "You disallowed guests" : "Zakázali ste hostí",
    "An administrator disallowed guests" : "Administrátor nepovolil hostí",
    "{actor} set a password" : "{actor} nastavil heslo",
    "You set a password" : "Nastavili ste heslo",
    "An administrator set a password" : "Administrátor nastavil heslo",
    "{actor} removed the password" : "{actor} zrušil heslo",
    "You removed the password" : "Zrušili ste heslo",
    "An administrator removed the password" : "Administrátor odstránil heslo",
    "{actor} added {user}" : "{actor} pridal {user}",
    "You joined the conversation" : "Pripojili ste sa k rozhovoru",
    "{actor} joined the conversation" : "Používateľ {actor} sa pripojil k rozhovoru",
    "You added {user}" : "Pridali ste {user}",
    "{actor} added you" : "{actor} Vás pridal",
    "An administrator added you" : "Pridal vás administrátor",
    "An administrator added {user}" : "Administrátor pridal {user}",
    "You left the conversation" : "Opustili ste rozhovor",
    "{actor} left the conversation" : "Používateľ {actor} opustil rozhovor",
    "{actor} removed {user}" : "{actor} odstránil {user}",
    "You removed {user}" : "Odstránili ste {user}",
    "{actor} removed you" : "{actor} Vás odstránil",
    "An administrator removed you" : "Administrátor vás odstránil",
    "An administrator removed {user}" : "Administrátor odstránil {user}",
    "{actor} invited {federated_user}" : " {actor} pozval {federated_user}",
    "You invited {federated_user}" : "Poslali ste pozvánku {federated_user}",
    "You accepted the invitation" : "Prijali ste pozvánku",
    "{actor} invited you" : "{actor} vás pozval",
    "An administrator invited you" : "Administrátor vás pozval",
    "An administrator invited {federated_user}" : "Administrátor pozval {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} akceptoval pozvánku",
    "{actor} removed {federated_user}" : "{actor} odstránil {federated_user}",
    "You removed {federated_user}" : "Odstránili ste {federated_user}",
    "You declined the invitation" : "Toto pozvanie ste odmietli",
    "An administrator removed {federated_user}" : "Administrátor odstránil {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} odmietol pozvánku",
    "{actor} added group {group}" : "{actor} pridal skupinu {group}",
    "You added group {group}" : "Pridali ste skupinu {group}",
    "An administrator added group {group}" : "Administrátor bol pridaný do skupiny {group}",
    "{actor} removed group {group}" : "{actor} odstránil skupinu {group}",
    "You removed group {group}" : "Odstránili ste skupinu {group}",
    "An administrator removed group {group}" : "Administrátor odstránil skupinu {group}",
    "{actor} added team {circle}" : "{actor} pridal tím {circle}",
    "You added team {circle}" : "Pridali ste tím {circle}",
    "An administrator added team {circle}" : "Administrátor pridal tím {circle}",
    "{actor} removed team {circle}" : "{actor} odobral tím {circle}",
    "You removed team {circle}" : "Odobrali ste tím {circle}",
    "An administrator removed team {circle}" : "Administrátor odobral tím {circle}",
    "{actor} added {phone}" : "{actor} pridal {phone}",
    "You added {phone}" : "Pridali ste {phone}",
    "An administrator added {phone}" : "Administrátor pridal {phone}",
    "{actor} removed {phone}" : "{actor} odstránil {phone}",
    "You removed {phone}" : "Odstránili ste {phone}",
    "An administrator removed {phone}" : "Administrátor odstránil {phone}",
    "{actor} promoted {user} to moderator" : "{actor} povýšil {user} na moderátora",
    "You promoted {user} to moderator" : "Povýšili ste {user} na moderátora",
    "{actor} promoted you to moderator" : "{actor} Vás povýšil na moderátora",
    "An administrator promoted you to moderator" : "Administrátor vás zadal ako moderátora",
    "An administrator promoted {user} to moderator" : "Administrátor zadal {user} ako moderátora",
    "{actor} demoted {user} from moderator" : "{actor} odobral {user} moderovanie",
    "You demoted {user} from moderator" : "Odobrali ste {user} moderovanie",
    "{actor} demoted you from moderator" : "{actor} Vám odobral moderovanie",
    "An administrator demoted you from moderator" : "Administrátor vás zrušil ako moderátora",
    "An administrator demoted {user} from moderator" : "Administrátor zrušil {user} ako moderátora",
    "{actor} shared a file which is no longer available" : "{actor} sprístupnil súbor ktorý už nie je dostupný",
    "You shared a file which is no longer available" : "Sprístupnili ste súbor ktorý už nie je dostupný",
    "File shares are currently not supported in federated conversations" : "Zdieľanie súborov v súčasnosti nie je podporované vo federatívnych konverzáciách",
    "The shared location is malformed" : "Zdieľané umiestnenie je poškodené",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} nastavil Matterbridge na synchronizáciu tejto konverzácie s inými rozhovormi.",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Nastavili ste Matterbridge na synchronizáciu tejto konverzácie s inými rozhovormi.",
    "{actor} created thread {title}" : "{actor} vytvoril vlákno {title}",
    "You created thread {title}" : "Vytvorili ste vlákno {title}",
    "{actor} renamed thread {title}" : "{actor} premenoval vlákno {title}",
    "You renamed thread {title}" : "Premenovali ste vlákno {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} aktualizoval nastavenie Matterbridge",
    "You updated the Matterbridge configuration" : "Aktualizovali ste nastavenie Matterbridge.",
    "{actor} removed the Matterbridge configuration" : "{actor} odstránil nastavenie Matterbridge",
    "You removed the Matterbridge configuration" : "Odstránili ste nastavenie Matterbridge",
    "{actor} started Matterbridge" : "{actor} spustil Matterbridge",
    "You started Matterbridge" : "Spustili ste Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} zastavil Matterbridge",
    "You stopped Matterbridge" : "Zastavili ste Matterbridge",
    "{actor} deleted a message" : "{actor} zmazal správu",
    "You deleted a message" : "Zmazali ste správu",
    "{actor} edited a message" : "{actor} upravil správu",
    "You edited a message" : "Upravili ste správu",
    "{actor} pinned a message" : "{actor} pripol správu",
    "You pinned a message" : "Pripli ste správu",
    "{actor} unpinned a message" : "{actor} odopol správu",
    "Message was automatically unpinned" : "Správa bola automaticky odopnutá",
    "You unpinned a message" : "Odopli ste správu",
    "{actor} deleted a reaction" : "{actor} vymazal reakciu",
    "You deleted a reaction" : "Odstránili ste reakciu",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Nastavili ste platnosť správy na %n týždeň","Nastavili ste platnosť správy na %n týždne","Nastavili ste platnosť správy na %n týždňov","Nastavili ste platnosť správy na %n týždne"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Nastavili ste platnosť správy na %n deň","Nastavili ste platnosť správy na %n dni","Nastavili ste platnosť správy na %n dní","Nastavili ste platnosť správy na %n dni"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Nastavili ste platnosť správy na %n hodinu","Nastavili ste platnosť správy na %n hodiny","Nastavili ste platnosť správy na %n hodín","Nastavili ste platnosť správy na %n hodiny"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Nastavili ste platnosť správy na %n minútu","Nastavili ste platnosť správy na %n minúty","Nastavili ste platnosť správy na %n minút","Nastavili ste platnosť správy na %n minúty"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} nastavil platnosť správy na %n týždeň","{actor} nastavil platnosť správy na %n týždne","{actor} nastavil platnosť správy na %n týždňov","{actor} nastavil platnosť správy na %n týždne"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} nastavil platnosť správy na %n deň","{actor} nastavil platnosť správy na %n dni","{actor} nastavil platnosť správy na %n dní","{actor} nastavil platnosť správy na %n dni"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} nastavil platnosť správy na %n hodinu","{actor} nastavil platnosť správy na %n hodiny","{actor} nastavil platnosť správy na %n hodín","{actor} nastavil platnosť správy na %n hodiny"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} nastavil platnosť správy na %n minútu","{actor} nastavil platnosť správy na %n minúty","{actor} nastavil platnosť správy na %n minút","{actor} nastavil platnosť správy na %n minúty"],
    "{actor} disabled message expiration" : "{actor} zakázal vypršanie platnosti správy",
    "You disabled message expiration" : "Zakázali ste vypršanie platnosti správy",
    "{actor} cleared the history of the conversation" : "{actor} vyčistil históriu konverzácie",
    "You cleared the history of the conversation" : "Vyčistili ste históriu konverzácie",
    "{actor} set the conversation picture" : "{actor} nastavil(a) obrázok konverzácie",
    "You set the conversation picture" : "Nastavili ste obrázok konverzácie",
    "{actor} removed the conversation picture" : "{actor} odstránil(a) obrázok konverzácie",
    "You removed the conversation picture" : "Odstránili ste obrázok konverzácie",
    "{actor} ended the poll {poll}" : "{actor} ukončil anketu {poll}",
    "You ended the poll {poll}" : "Ukončili ste anketu {poll}",
    "{actor} started the video recording" : "{actor} spustil(a) nahrávanie videa",
    "You started the video recording" : "Spustili ste nahrávania videa",
    "{actor} stopped the video recording" : "{actor} zastavil(a) nahrávanie videa",
    "You stopped the video recording" : "Zastavili ste nahrávanie videa",
    "{actor} started the audio recording" : "{actor} spustil(a) nahrávanie zvuku",
    "You started the audio recording" : "Spustili ste nahrávanie zvuku",
    "{actor} stopped the audio recording" : "{actor} zastavil nahrávanie zvuku",
    "You stopped the audio recording" : "Zastavili ste nahrávanie zvuku",
    "The recording failed" : "Nahrávanie skončilo s chybou",
    "Someone voted on the poll {poll}" : "Niekto hlasoval v ankete {poll}",
    "Message deleted by author" : "Správa vymazaná autorom",
    "Message deleted by {actor}" : "Správa vymazaná od {actor}",
    "Message deleted by you" : "Správu ste odstránili",
    "Deleted user" : "Zmazaný užívateľ",
    "Unknown number" : "Neznáme číslo",
    "Administration" : "Administrácia",
    "System" : "Systém",
    "%s (guest)" : "%s (guest)",
    "Missed call" : "Zmeškaný hovor",
    "Unanswered call" : "Neprijatý hovor",
    "Call ended (Duration {duration})" : "Hovor skončil (Doba hovoru {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} ukončil hovor (Doba hovoru {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Hovor s %n návštevníkom bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Hovor s %n návštevníkom bol ukončený (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený (Doba hovoru {duration})","Hovor s %n návštevníkmi bol ukončený (Doba hovoru {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ukončil hovor s %n návštevníkom (Trvanie {duration})","{actor} ukončil hovor s %n návštevníkmi (Trvanie {duration})","{actor} ukončil hovor s %n návštevníkmi (Trvanie {duration})","{actor} ukončil hovor s %n návštevníkmi (Trvanie {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1} bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "Call with {user1} ended (Duration {duration})" : "Hovor s {user1} bol ukončený  (Doba hovoru {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ukončil hovor s {user1}  (Trvanie {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1} a {user2} bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Hovor s {user1} a {user2} bol ukončený (Doba hovoru {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ukončil hovor s {user1} a {user2} (Trvanie {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1},  {user2}  a {user3} bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Hovor s {user1}, {user2} a {user3} ukončený (Doba hovoru {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2} a {user3} (Trvanie {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1}, {user2}, {user3} a {user4} bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Hovor s {user1}, {user2}, {user3} a {user4} ukončený (Doba hovoru {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2}, {user3} a {user4} (Trvanie {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Hovor s {user1}, {user2}, {user3}, {user4} a {user5} bol ukončený, keďže dosiahol maximálnu dĺžku hovoru (Doba hovoru {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Hovor s {user1}, {user2}, {user3}, {user4} a {user5} ukončený (Doba hovoru {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ukončil hovor s {user1}, {user2}, {user3}, {user4} a {user5} (Trvanie {duration})",
    "Message of {user} in {conversation}" : "Správa od {author} v {conversation}",
    "Message of {user}" : "Správa od {user}",
    "Message of a deleted user in {conversation}" : "Správa od zmazaného užívateľa v {conversation}",
    "Talk conversations" : "Talk /Rozhovor/ konverzácia",
    "Talk to %s" : "Talk /Rozhovor/ s %s",
    "An error occurred. Please contact your administrator." : "Vyskytla sa chyba. Prosím, kontaktujte svojho správcu.",
    "App disabled" : "Aplikácia vypnutá",
    "Conversation subfolders are disabled" : "Podpriečinky konverzácie sú vypnuté",
    "Storage quota exceeded" : "Kapacita úložiska prekročená",
    "Could not prepare conversation folder" : "Nepodarilo sa pripraviť priečinok konverzácie",
    "File not found" : "Súbor nenájdený",
    "Path must point to a file" : "Cesta musí smerovať k súboru",
    "File is not inside the conversation draft folder for this room" : "Súbor nie je vo vnútri priečinka konceptov konverzácie pre túto miestnosť",
    "File is not shared, or shared but not with the user" : "Súbor nie je sprístupnený alebo je sprístupnený inému používateľovi",
    "No account available to delete." : "Na odstránenie nie je k dispozícii žiadny účet.",
    "Poll" : "Anketa",
    "Password needs to be set" : "Heslo musí byť nastavené",
    "Uploading the file failed" : "Nahrávanie súboru zlyhalo",
    "No image file provided" : "Súbor obrázku nebol zadaný",
    "File is too big" : "Súbor je príliš veľký",
    "Invalid file provided" : "Zadaný neplatný súbor",
    "Invalid image" : "Chybný obrázok",
    "Unknown filetype" : "Neznámy typ súboru",
    "Talk mentions" : "Zmienky v Talk /Rozhovore/",
    "More conversations" : "Viac konverzácií",
    "Say hi to your friends and colleagues!" : "Pozdravte svojich priateľov a kolegov!",
    "No unread mentions" : "Žiadne neprečítané upozornenia",
    "Call in progress" : "Prebieha hovor",
    "You were mentioned" : "Boli ste spomenutí",
    "Write to conversation" : "Napísať do rozhovoru",
    "Writes event information into a conversation of your choice" : "Napíše informáce o udalosti do rozhovoru, ktorý vyberiete",
    "Missing email field in header line" : "V riadku hlavičky chýba pole e-mailu",
    "Following lines are invalid: %s" : "Nasledujúce riadky nie sú platné: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s ťa pozval/a na rozhovor \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Boli ste pozvaní na konverzáciu \"%s\".",
    "Conversation invitation" : "Prizvanie ku konverzácii",
    "Scheduled time" : "Naplánovaný čas",
    "Description" : "Popis",
    "You can also dial-in via phone with the following details" : "Môžete sa tiež pripojiť telefonicky pomocou nasledujúcich podrobností",
    "Dial-in information" : "Informácia o prichádzajúcom volaní.",
    "Meeting ID" : "ID schôdzky",
    "Your PIN" : "Váš PIN",
    "Click the button below to join the lobby now." : "Kliknite na tlačidlo nižšie a pripojte sa do čakárne teraz.",
    "Click the link below to join the lobby now." : "Kliknite na nižšie uvedený odkaz a pripojte sa do čakárne teraz.",
    "Join lobby for \"%s\"" : "Pripojiť sa do čakárne \"%s\"",
    "Click the button below to join the conversation now." : "Kliknite na tlačidlo nižšie a pripojte sa k rozhovoru teraz.",
    "Click the link below to join the conversation now." : "Kliknite na nižšie uvedený odkaz a pridajte sa do rozhovoru teraz.",
    "Join \"%s\"" : "Pripojiť sa k \"%s\"",
    "Meeting" : "Porada",
    "Password request: %s" : "Požiadavka na heslo: %s",
    "Private conversation" : "Súkromná konverzácia",
    "Deleted user (%s)" : "Odstránený používateľ (%s)",
    "Failed to upload call recording" : "Chyba pri nahrávaní záznamu hovoru",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Záznamový server zlyhal pri nahrávaní nahrávky hovoru {call}. Prosím, obráťte sa na administráciu.",
    "Share to chat" : "Zdieľať v chate",
    "Dismiss notification" : "Zatvoriť upozornenie",
    "Call recording now available" : "Nahrávka hovoru je teraz dostupná",
    "The recording for the call in {call} was uploaded to {file}." : "Záznam hovoru v {call} bol nahraný do {file}.",
    "Transcript now available" : "Prepisovanie na text je teraz k dispozícii",
    "The transcript for the call in {call} was uploaded to {file}." : "Záznam prepisu na text hovoru v {call} bol nahraný do {file}.",
    "Failed to transcript call recording" : "Nepodarilo sa prepísať na text nahrávku hovoru",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Server sa nepodarilo prepísať na text nahrávku v súbore {file} pre hovor {call}. Prosím, obráťte sa na administráciu.",
    "Call summary now available" : "Zhrnutie hovoru je pripravené",
    "The summary for the call in {call} was uploaded to {file}." : "Zhrnutie hovoru {call} bolo nahrané do {file}.",
    "Failed to summarize call recording" : "Nepodarilo sa vytvoriť zhrnutie záznamu hovoru",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveru sa nepodarilo zhrnúť nahrávku v súbore {file} pre hovor v {call}. Prosím, kontaktujte administráciu.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} ťa pozval, aby si sa pripojil k miestnosti {roomName} na {remoteServer}",
    "Accept" : "Prijať",
    "Decline" : "Zahodiť",
    "{user1} invited you to a federated conversation" : "Používateľ {user1} vás pozval ku federovanému rozhovoru",
    "Someone reacted" : "Niekto reagoval",
    "New message" : "Nová správa",
    "Reminder" : "Pripomienka",
    "Someone mentioned you" : "Niekto ťa spomenul",
    "Notification" : "Oznámenie",
    "Someone reacted in a private conversation" : "Niekto reagoval v súkromnej konverzácii",
    "You received a message in a private conversation" : "Dostali ste správu v súkromnej konverzácii",
    "Reminder in a private conversation" : "Pripomienka v súkromnej konverzácii",
    "Someone mentioned you in a private conversation" : "Niekto ťa spomenul v súkromnej konverzácii",
    "Notification in a private conversation" : "Oznámenie v súkromnej konverzácii",
    "Reminder: You in {call}" : "Pripomienka: Vy v {call}",
    "Reminder: {user} in {call}" : "Pripomienka: {user} v {call}",
    "Reminder: Deleted user in {call}" : "Pripomienka: Odstránený používateľ v {call}",
    "Reminder: {guest} (guest) in {call}" : "Pripomienka: {guest} (hosť) v {call}",
    "Reminder: Guest in {call}" : "Pripomienka: Hosť v {call}",
    "{user} reacted with {reaction}" : "{user} zareagoval s {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} zareagoval s {reaction} v {call}",
    "Deleted user reacted with {reaction} in {call}" : "Vymazaný užívateľ zareagoval s {reaction} v {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (hosť) zareagoval s {reaction} v {call}",
    "Guest reacted with {reaction} in {call}" : "Hosť reagoval s {reaction} v {call}",
    "{user} in {call}" : "{user} v {call}",
    "Deleted user in {call}" : "Odstránený užívateľ v {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) v {call}",
    "Guest in {call}" : "Hosť v {call}",
    "{user} sent you a private message" : "{user} Vám poslal súkromnú správu",
    "{user} sent a message in conversation {call}" : "Používateľ {user} odoslal správu v rozhovore {call}",
    "A deleted user sent a message in conversation {call}" : "Odstránený používateľ odoslal správu v rozhovore {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (hosť) poslal(a) správu v rozhovore {call}",
    "A guest sent a message in conversation {call}" : "Hosť odoslal správu v rozhovore {call}",
    "{user} replied to your private message" : "{user} odpovedal(a) na vašu súkromnú správu",
    "{user} replied to your message in conversation {call}" : "{user} odpovedal(a) na vašu správu v rozhovore {call}",
    "A deleted user replied to your message in conversation {call}" : "Odstránený používateľ odpovedal na vašu správu v rozhovore {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (hosť) odpovedal(a) na vašu správu v rozhovore {call}",
    "A guest replied to your message in conversation {call}" : "Hosť odpovedal na vašu správu v rozhovore {call}",
    "Reminder: You in private conversation {call}" : "Pripomienka: Ste v súkromnej konverzácii {call}",
    "Reminder: A deleted user in private conversation {call}" : "Pripomienka: Vymazaný užívateľ v súkromnej konverzácii {call}",
    "Reminder: {user} in private conversation" : "Pripomienka: {user} v súkromnej konverzácii",
    "Reminder: You in conversation {call}" : "Pripomienka: Ste v konverzácii {call}",
    "Reminder: {user} in conversation {call}" : "Pripomienka: {user} v konverzácii {call}",
    "Reminder: A deleted user in conversation {call}" : "Pripomienka: Vymazaný užívateľ v konverzácii {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Pripomienka: {guest} (hosť) v konverzácii {call}",
    "Reminder: A guest in conversation {call}" : "Pripomienka: Hosť v konverzácii {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reagoval {reaction} na vašu súkromnú správu",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reagoval(a) {reaction} na vašu správu v rozhovore {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Odstránený používateľ reagoval(a) {reaction} na vašu správu v rozhovore {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (návštevník) reagoval(a) {reaction} na vašu správu v rozhovore {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Návštevník reagoval(a) {reaction} na vašu správu v rozhovore {call}",
    "{user} mentioned you in a private conversation" : "Používateľ {user} vás spomenul v súkromnom rozhovore",
    "{user} mentioned group {group} in conversation {call}" : "{user} spomenul skupinu {group} v konverzácii {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} spomenul/a {team} v konverzácii {call}",
    "{user} mentioned everyone in conversation {call}" : "Užívateľ {user} spomenul všetkých v rozhovore {call}",
    "{user} mentioned you in conversation {call}" : "Používateľ {user} vás spomenul v rozhovore {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Odstránený užívateľ spomenul skupinu {group} v konverzácii {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Vymazaný používateľ spomenul tím {team} v konverzácii {call}.",
    "A deleted user mentioned everyone in conversation {call}" : "Odstránený užívateľ spomenul všetkých v rozhovore {call}",
    "A deleted user mentioned you in conversation {call}" : "Odstránený používateľ vás spomenul v rozhovore {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (hosť) spomenul skupinu {group} v konverzácii {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (hosť) spomenul tím {team} v rozhovore {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "Užívateľ {guest} spomenul všetkých v rozhovore {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (hosť) vás spomenul v rozhovore {call}",
    "A guest mentioned group {group} in conversation {call}" : "Hosť spomenul skupinu {group} v konverzácii {call}",
    "A guest mentioned team {team} in conversation {call}" : "Hosť spomenul tím {team} v konverzácii {call}",
    "A guest mentioned everyone in conversation {call}" : "Hosť vás spomenul v rozhovore {call}",
    "A guest mentioned you in conversation {call}" : "Hosť vás spomenul v rozhovore {call}",
    "View message" : "Zobraziť správu",
    "Dismiss reminder" : "Zatvoriť pripomienku",
    "View chat" : "Zobraziť čet",
    "{user} invited you to a group conversation: {call}" : "Používateľ {user} vás prizval ku skupinovému rozhovoru: {call}",
    "Join call" : "Pripojiť sa k hovoru",
    "Answer call" : "Prijať hovor",
    "{user} would like to talk with you" : "{user} by sa chcel s vami porozprávať",
    "Call back" : "Zavolať späť",
    "You missed a call from {user}" : "Zmeškali ste hovor od používateľa {user}",
    "Accept call" : "Prijať hovor",
    "Incoming phone call from {call}" : "Prichádzajúci hovor od {call}",
    "You missed a phone call from {call}" : "Zmeškali ste hovor od {call}",
    "A group call has started in {call}" : "Skupinový hovor začal v {call}",
    "You missed a group call in {call}" : "Zmeškali ste skupinový hovor v {call}",
    "{email} is requesting the password to access {file}" : "{email} požaduje heslo pre prístup k {súboru}",
    "{email} tried to request the password to access {file}" : "{email} sa pokúsil požiadať o heslo pre prístup k {file}",
    "Someone is requesting the password to access {file}" : "Niekto požaduje heslo pre prístup k {file}",
    "Someone tried to request the password to access {file}" : "Niekto sa pokúsil požiadať o heslo pre prístup k {file}",
    "Open settings" : "Otvoriť nastavenia",
    "Hosted signaling server added" : "Hostovaný signalizačný server pridaný",
    "The hosted signaling server is now configured and will be used." : "Teraz je nastavený hosťovaný signalizačný server a bude sa používať.",
    "Hosted signaling server removed" : "Hostovaný signalizačný server odstránený",
    "The hosted signaling server was removed and will not be used anymore." : "Hosťovaný signalizačný server bol odstránený a už sa nebude používať.",
    "Hosted signaling server changed" : "Hostovaný signalizačný server zmenený",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Účet hosťovaného signalizačného servera zmenil stav z \"{oldstatus}\" na \"{newstatus}\".",
    "pending" : "čakajúce",
    "active" : "aktívne",
    "expired" : "expirované",
    "blocked" : "blokované",
    "error" : "chyba",
    "The certificate of {host} expires in {days} days" : "Certifikát pre {host} vyprší o {days} dní",
    "The certificate of {host} expired" : "Certifikát pre {host} vypršal",
    "Contact via Talk" : "Kontaktovať cez Talk /Rozhovor/",
    "Open Talk" : "Otvoriť Talk /Rozhovor/",
    "Default" : "Predvolené",
    "Send messages, create threads, and start voice and video calls." : "Odosielajte správy, vytvárajte vlákna a začnite hlasové a videohovory.",
    "Presentation" : "Prezentácia",
    "Voice room" : "Hlasová miestnosť",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Priamo sa pripojte k hovoru, ideálne na rýchle aktualizácie alebo spontánne stretnutia.",
    "Webinar" : "Webinár",
    "Conversations" : "Konverzácie",
    "Messages in current conversation" : "Správy v aktuálnej konverzácii",
    "{user}" : "{user}",
    "Messages" : "Správy",
    "{user} in {conversation}" : "{user} v {conversation}",
    "Messages in other conversations" : "Správy v iných konverzáciách",
    "One-to-one rooms always need to show the other users avatar" : " Miestnosti jeden na jedného musia vždy zobraziť avatara ostatných užívateľov.",
    "Invalid emoji character" : "Neplatný znak emotikonu",
    "Invalid background color" : "Neplatná farba pozadia",
    "Avatar image is not square" : "Obrázok avatara nie je štvorcový",
    "Room {number}" : "Miestnosť {number}",
    "Other" : "Iné",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Nepodarilo sa požiadať o skúšobnú verziu, pretože skúšobný server je nedostupný. Skúste to neskôr.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Vyskytol sa problém s overením tejto inštancie. Možno nie je zvonka prístupná zvonku na overenie jej URL.",
    "Something unexpected happened." : "Stalo sa niečo neočakávané.",
    "The URL is invalid." : "URL je neplatná.",
    "An HTTPS URL is required." : "Je vyžadovaná HTTPS URL.",
    "The email address is invalid." : "E-mailová adresa je neplatná.",
    "The language is invalid." : "Jazyk je neplatný.",
    "The country is invalid." : "Krajina je neplatná.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Vyskytol sa problém so skúšobnou verziou. ďalšie informácie získate v záznamoch udalostí.",
    "Too many requests are send from your servers address. Please try again later." : "Z adresy servera sa odoslalo príliš veľa požiadaviek. Skúste to neskôr prosím.",
    "There is already a trial registered for this Nextcloud instance." : "Pre túto inštanciu Nextcloud je už zaregistrovaná skúšobná verzia.",
    "Something unexpected happened. Please try again later." : "Stalo sa niečo neočakávané. Skúste to neskôr prosím.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Nepodarilo sa požiadať o skúšobnú verziu, pretože skúšobný server sa správal chybne. Skúste to neskôr.",
    "Trial requested but failed to get account information. Please check back later." : "Požiadavka o skúšobnú verziu bola odoslaná, ale nepodarilo sa získať informácie o účte. Skúste to znova neskôr.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Vyskytol sa problém s overením tejto požiadavky. Možno nie je zvonku prístup na overenie jej URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Nepodarilo sa načítať informácie o účte, pretože skúšobný server sa správal chybne. Skúste to znova neskôr.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Vyskytol sa problém s načítaním informácií o účte. Skontrolujte ďalšie informácie v záznamoch udalostí.",
    "There is no such account registered." : "Takýto účet nie je zaregistrovaný.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Nepodarilo sa načítať informácie o účte, pretože skúšobný server je nedostupný. Skúste to znova neskôr.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Odstránenie účtu hosťovaného signalizačného servera zlyhalo. Skúste to znova neskôr.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Nepodarilo sa odstrániť účet, pretože skúšobný server sa správal chybne. Skúste to znova neskôr.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Vyskytol sa problém s odstránením účtu. Ďalšie informácie získate v záznamoch udalostí.",
    "Too many requests are sent from your servers address. Please try again later." : "Z adresy servera sa odoslalo príliš veľa požiadaviek. Skúste to neskôr prosím.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Nepodarilo sa odstrániť účet, pretože skúšobný server je nedostupný. Skúste to znova neskôr.",
    "Note to self" : "Poznámka pre seba",
    "A place for your private notes, thoughts and ideas" : "Miesto pre vaše súkromné poznámky, myšlienky a nápady",
    "Transcript is AI generated and may contain mistakes" : "Prepis je generovaný umelou inteligenciou a môže obsahovať chyby",
    "Summary is AI generated and may contain mistakes" : "Zhrnutie je generované umelou inteligenciou a môže obsahovať chyby",
    "Let's get started!" : "Poďme začať!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** je bezpečná komunikačná platforma na vlastnom serveri, ktorá sa hladko integruje do ekosystému Nextcloud.\n\n#### Kľúčové vlastnosti Nextcloud Talk:\n\n* Chat a správy v súkromných a skupinových chatoch\n* Hlasové hovory a videohovory\n* Zdieľanie súborov a integrácia s inými aplikáciami Nextcloud\n* Prispôsobiteľné nastavenia konverzácie, moderovanie a ovládanie súkromia\n* Web, počítač a mobil (iOS a Android)\n* Súkromná a bezpečná komunikácia\n\nViac informácií nájdete v [používateľskej dokumentácii](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Vitajte v Nextcloud Talk\n\nNextcloud Talk je súkromná a výkonná aplikácia na odosielanie správ, ktorá sa integruje s Nextcloud. Chatujte v súkromných alebo skupinových konverzáciách, spolupracujte prostredníctvom hlasových hovorov a videohovorov, organizujte webináre a udalosti, prispôsobujte si konverzácie a ďalšie.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formátujte texty pre vytváranie formátovaných správ\n\nV Nextcloud Talk môžete použiť syntax Markdown na formátovanie správ. Použite napríklad formátovanie **tučné** alebo *kurzíva* alebo „zvýraznenie textov ako kódu“. Môžete dokonca vytvárať tabuľky a pridávať nadpisy do textu.\n\nPotrebujete opraviť preklep alebo zmeniť formátovanie? Upravte svoju správu kliknutím na „Upraviť správu“ v ponuke správ.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Pridajte prílohy a odkazy\n\nPripojte súbory z vášho Nextcloud Hub pomocou tlačidla „+“. Zdieľajte položky zo súborov a rôznych aplikácií Nextcloud. Niektoré aplikácie dokonca podporujú interaktívne miniaplikácie, napríklad aplikácia Text.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Nechajte konverzácie plynúť: spomínajte používateľov, reagujte na správy a viac.\n\nV konverzácii môžete spomenúť každého použitím %s alebo konkrétnych účastníkov tak, že napíšete \"@\" a vyberiete ich meno zo zoznamu.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Môžete odpovedať na správy, preposielať ich do ďalších chatov a ľuďom alebo kopírovať obsah správy.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Urobte viac pomocou funkcie Smart Picker\n\nJednoducho napíšte „/“ alebo prejdite do ponuky „+“ a otvorte Smart Picker, kde môžete k svojim správam pripojiť rôzny obsah. Inteligentný výber môžete nakonfigurovať tak, aby bolo možné pridávať položky z aplikácií Nextcloud, súbory GIF, miesta na mape, obsah generovaný AI a oveľa viac.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Spravujte nastavenia konverzácie\n\nV ponuke konverzácie máte prístup k rôznym nastaveniam na správu konverzácií, ako napríklad:\n* Upravte informácie o konverzácii\n* Spravujte upozornenia\n* Aplikujte početné pravidlá moderovania\n* Nakonfigurujte prístup a zabezpečenie\n* Povoľte roboty\n* a ďalšie!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Spojené Arabské Emiráty",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua a Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánsko",
    "Armenia" : "Arménsko",
    "Angola" : "Angola",
    "Antarctica" : "Antarktída",
    "Argentina" : "Argentína",
    "American Samoa" : "Americká Samo",
    "Austria" : "Rakúsko",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Alandy",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna a Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladéš",
    "Belgium" : "Belgicko",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulharsko",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Svätý Bartolomej",
    "Bermuda" : "Bermudy",
    "Brunei Darussalam" : "Brunej-Darussalam",
    "Bolivia, Plurinational State of" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius a Saba",
    "Brazil" : "Brazília",
    "Bahamas" : "Bahamské ostrovy",
    "Bhutan" : "Bhután",
    "Bouvet Island" : "Bouvetský ostrov",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorusko",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosové ostrovy",
    "Congo, the Democratic Republic of the" : "Kongo",
    "Central African Republic" : "Stredoafrická republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švajčiarsko",
    "Côte d'Ivoire" : "Pobrežie Slonoviny",
    "Cook Islands" : "Cookove ostrovy",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Čína",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapverdy",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Vianočný ostrov",
    "Cyprus" : "Cyprus",
    "Czechia" : "Česká repubika",
    "Germany" : "Nemecko",
    "Djibouti" : "Džibutsko",
    "Denmark" : "Dánsko",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikánska republika",
    "Algeria" : "Alžírsko",
    "Ecuador" : "Ekvádor",
    "Estonia" : "Estónsko",
    "Egypt" : "Egypt",
    "Western Sahara" : "Západná Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Španielsko",
    "Ethiopia" : "Etiópia",
    "Finland" : "Fínsko",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Falklandské ostrovy",
    "Micronesia, Federated States of" : "Mikronézia",
    "Faroe Islands" : "Faerské ostrovy",
    "France" : "Francúzsko",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Spojené kráľovstvo Veľkej Británie a Severného Írska",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzínsko",
    "French Guiana" : "Francúzska Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltár",
    "Greenland" : "Grónsko",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Rovníková Guinea",
    "Greece" : "Grécko",
    "South Georgia and the South Sandwich Islands" : "Južná Georgia a Južné Sandwichove ostrovy",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heardove a McDonaldove ostrovy",
    "Honduras" : "Honduras",
    "Croatia" : "Chorvátsko",
    "Haiti" : "Haiti",
    "Hungary" : "Maďarsko",
    "Indonesia" : "Indonézia",
    "Ireland" : "Írsko",
    "Israel" : "Izrael",
    "Isle of Man" : "ostrov Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Britské indickooceánske územie",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Irán",
    "Iceland" : "Island",
    "Italy" : "Taliansko",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordánsko",
    "Japan" : "Japonsko",
    "Kenya" : "Keňa",
    "Kyrgyzstan" : "Kirgizsko",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komory",
    "Saint Kitts and Nevis" : "Svätý Krištof a Nevis",
    "Korea, Democratic People's Republic of" : "Severná Kórea",
    "Korea, Republic of" : "Južná Kórea",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanské ostrovy",
    "Kazakhstan" : "Kazachstan",
    "Lao People's Democratic Republic" : "Laoská ľudovodemokratická republika",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Svätá Lucia",
    "Liechtenstein" : "Lichtenštajnsko",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesothské kráľovstvo",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luxembursko",
    "Latvia" : "Lotyšsko",
    "Libya" : "Líbia",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldavská republika",
    "Montenegro" : "Čierna Hora",
    "Saint Martin (French part)" : "Svätý Martin (francúzska časť)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshallove ostrovy",
    "North Macedonia" : "Severné Macedónsko",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmarsko",
    "Mongolia" : "Mongolsko",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Severné Mariany",
    "Martinique" : "Martinik",
    "Mauritania" : "Mauritánia",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Maurícius",
    "Maldives" : "Maledivy",
    "Malawi" : "Malawi",
    "Mexico" : "Mexiko",
    "Malaysia" : "Malajzia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nová Kaledónia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandsko",
    "Norway" : "Nórsko",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nový Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francúzska Polynézia",
    "Papua New Guinea" : "Papua-Nová Guinea",
    "Philippines" : "Filipíny",
    "Pakistan" : "Pakistan",
    "Poland" : "Poľsko",
    "Saint Pierre and Miquelon" : "Saint Pierre a Miquelon",
    "Pitcairn" : "Pitcairnove ostrovy",
    "Puerto Rico" : "Portoriko",
    "Palestine, State of" : "Palestína",
    "Portugal" : "Portugalsko",
    "Palau" : "Palau",
    "Paraguay" : "Paraguaj",
    "Qatar" : "Katar",
    "Réunion" : "Reunion",
    "Romania" : "Rumunsko",
    "Serbia" : "Srbsko",
    "Russian Federation" : "Ruská federácia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudská Arábia",
    "Solomon Islands" : "Šalamúnove ostrovy",
    "Seychelles" : "Seychely",
    "Sudan" : "Sudán",
    "Sweden" : "Švédsko",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Svätá Helena, Ascension a Tristan da Cunha",
    "Slovenia" : "Slovinsko",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovensko",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Maríno",
    "Senegal" : "Senegal",
    "Somalia" : "Somálsko",
    "Suriname" : "Surinam",
    "South Sudan" : "Južný Sudán",
    "Sao Tome and Principe" : "Svätý Tomáš a Princov ostrov",
    "El Salvador" : "Salvádor",
    "Sint Maarten (Dutch part)" : "Sint Maarten (holandská časť)",
    "Syrian Arab Republic" : "Sýria",
    "Eswatini" : "Svazijsko",
    "Turks and Caicos Islands" : "ostrovy Turks a Caicos",
    "Chad" : "Čad",
    "French Southern Territories" : "Francúzska južná a antarktická oblasť",
    "Togo" : "Togo",
    "Thailand" : "Thajsko",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Východný Timor",
    "Turkmenistan" : "Turkménsko",
    "Tunisia" : "Tunisko",
    "Tonga" : "Tonga",
    "Turkey" : "Turecko",
    "Trinidad and Tobago" : "Trinidad a Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzánia",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Menšie odľahlé ostrovy Spojených štátov",
    "United States of America" : "Spojené štáty americké",
    "Uruguay" : "Uruguaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Vatikán",
    "Saint Vincent and the Grenadines" : "Svätý Vincent a Grenadíny",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Britské Paneské ostrovy",
    "Virgin Islands, U.S." : "U.S. Panenské ostrovy",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Juhoafrická republika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Rozmazanie pozadia",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nepodarilo sa skontrolovať podporu načítania WASM. Prosím skontrolujte manuálne, či váš webový server poskytuje súbory `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Váš webový server nie je správne nastavený na doručovanie súborov `.wasm`. Toto je zvyčajne problém s konfiguráciou Nginx. Pre rozostrenie pozadia potrebuje úpravu, aby doručoval aj súbory `.wasm`. Porovnajte svoju konfiguráciu Nginx s odporúčanou konfiguráciou v našej dokumentácii.",
    "Talk configuration values" : "Konfiguračné hodnoty aplikácie Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Vynútenie trvania hovoru je podporované iba systémovým cronom. Povoľte systémový cron alebo odstráňte konfiguráciu `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Malé hodnoty „max_call_duration“ (momentálne nastavené na %d) nie sú vynútiteľné z dôvodu technických obmedzení. Úloha na pozadí sa vykonáva iba každých 5 minút, takže použitie na vlastné riziko.",
    "Federation" : "Združovanie",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Dôrazne sa odporúča nakonfigurovať \"memcache.locking\", keď je zapnutá Talk Federation.",
    "High-performance backend" : "Vysoko výkonná podporná vrstva",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nie je nakonfigurovaný vysokovýkonný backend - Spustenie Nextcloud Talk bez vysokovýkonného backendu je možné len pre veľmi malé hovory (max. 2-3 účastníci). Nastavte si vysokovýkonný backend, aby ste zabezpečili bezproblémové fungovanie hovorov s viacerými účastníkmi.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Spustenie vysokovýkonného backendového režimu „conversation_cluster“ je zastarané a v nadchádzajúcej verzii už nebude podporované. Vysokovýkonný backend v súčasnosti podporuje skutočné klastrovanie, ktoré by sa malo použiť namiesto neho.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definovanie viacerých vysokovýkonných backendov je zastarané a v pripravovanej verzii už nebude podporované. Namiesto toho by mal byť nastavený vyrovnávač zaťaženia spolu s klastrovými signalizačnými servermi a nakonfigurovaný v nastaveniach Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Uložený verejný kľúč pre použitý algoritmus %1$s sa nezhoduje s uloženým súkromným kľúčom. Spustite %2$s na opravu problému.",
    "High-performance backend not configured correctly. Run %s for details." : "Vysokovýkonný backend nie je správne nakonfigurovaný. Spustite %s pre podrobnosti.",
    "High-performance backend not configured correctly" : "Vysokovýkonný backend nie je správne nakonfigurovaný",
    "Error: Cannot connect to server" : "Chyba: Nedá sa pripojiť k serveru",
    "Error: Server did not respond with proper JSON" : "Chyba: Server neodpovedal správnym JSON",
    "Error: Certificate expired" : "Chyba: Certifikát vypršal",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Chyba: Systémové časy servera Nextcloud a vysokovýkonného servera backend nie sú synchronizované. Uistite sa, že sú oba servery pripojené k časovému serveru alebo manuálne synchronizujte ich čas.",
    "Could not get version" : "Nie je možné zistiť verziu",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Chyba: Spustené verzia: {version}; Server musí byť aktualizovaný pre kompatibilitu s touto verziou Rozhovoru",
    "Error: Server responded with: {error}" : "Chyba: Server odpovedal s: {error}",
    "Error: Unknown error occurred" : "Chyba: Vyskytla sa neznáma chyba",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Upozornenie: Bežiaca verzia: {version}; Server nepodporuje všetky funkcie tejto verzie Talk, chýbajúce funkcie: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Pri spustení Nextcloud Talk s vysokovýkonným backendom sa dôrazne odporúča nakonfigurovať vyrovnávaciu pamäť.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Klient Push je nainštalovaný, čo zlepšuje presnosť notifikácií v aplikácii Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} nie je nainštalovaný. To môže spôsobiť oneskorené oznámenia o hovore.",
    "Recording backend" : "Backend pre záznam",
    "Using the recording backend requires a High-performance backend." : "Používanie backendu nahrávania vyžaduje vysokovýkonný backend.",
    "No recording backend configured" : "Nie je nakonfigurovaný žiadny backend nahrávania",
    "SIP configuration" : "Nastavenie SIP",
    "Using the SIP functionality requires a High-performance backend." : "Používanie funkcionality SIP vyžaduje vysokovýkonný backend.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Pridelené telefónne čísla Talk nesmú začínať + alebo 0. Odstráňte alebo aktualizujte nasledujúce čísla:\n{list}",
    "No SIP backend configured" : "Nie je nakonfigurovaný žiadny SIP backend",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatný dátum, formát musí byť v tvare YYYY-MM-DD",
    "Conversation not found" : "Rozhovor sa nenašiel",
    "Path is already shared with this conversation" : "Cesta je už nazdieľaná v tejto konverzácii",
    "Chat, video & audio-conferencing using WebRTC" : "Čet, video a audio konferencie pomocou WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video a audiokonferencie pomocou WebRTC\n\n* 💬 **Chat** Nextcloud Talk prichádza s jednoduchým textovým chatom, ktorý vám umožňuje zdieľať alebo nahrávať súbory z vašej aplikácie Nextcloud Files alebo miestneho zariadenia a spomenúť ďalších účastníkov.\n* 👥 **Súkromné, skupinové, verejné a heslom chránené hovory!** Pozvite niekoho, celú skupinu alebo pošlite verejný odkaz na pozvanie na hovor.\n* 🌐 **Federované chaty** Chatujte s ostatnými používateľmi Nextcloud na ich serveroch\n* 💻 **Zdieľanie obrazovky!** Zdieľajte svoju obrazovku s účastníkmi vášho hovoru.\n* 🚀 **Integrácia s ďalšími aplikáciami Nextcloud**, ako sú Súbory, Kalendár, Stav používateľa, Dashboard, Flow, Mapy, Inteligentný výber, Kontakty, Deck a mnoho ďalších.\n* 🌉 **Synchronizácia s inými chatovacími riešeniami** Vďaka integrácii [Matterbridge](https://github.com/42wim/matterbridge/) do aplikácie Talk môžete jednoducho synchronizovať množstvo ďalších chatovacích riešení so službou Nextcloud Talk a naopak.",
    "Leave call" : "Opustiť hovor",
    "Navigating away from the page will leave the call in {conversation}" : "Ak opustíte stránku, hovor ostane v {conversation}",
    "Stay in call" : "Neopustiť hovor",
    "Error occurred when getting the conversation information" : "Došlo k chybe pri získavaní informácií o konverzácii",
    "Discuss this file" : "Diskutujte o tomto súbore",
    "Share this file with others to discuss it" : "Zdieľajte tento súbor s ostatnými a diskutujte o ňom",
    "Share this file" : "Zdieľať tento súbor",
    "Join conversation" : "Pripojiť sa ku konverzácii",
    "This conversation is password-protected." : "Táto konverzácia je chránená heslom.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
    "The password is wrong. Try again." : "Heslo je nesprávne. Skúste znova.",
    "Password" : "Heslo",
    "Submit" : "Odoslať",
    "Error requesting the password." : "Chyba pri vyžiadaní hesla",
    "Request password" : "Vyžiadať heslo",
    "This conversation has ended" : "Tento rozhovor bol ukončený",
    "Error occurred when joining the conversation" : "Nastala chyba pri pripájaní ku konverzácii",
    "Close Talk sidebar" : "Zavrieť bočný panel Rozhovor",
    "Open Talk sidebar" : "Otvoriť bočný panel Rozhovoru",
    "Everyone" : "Všetci",
    "Users and moderators" : "Používatelia a moderátori",
    "Moderators only" : "Iba moderátori",
    "Disable calls" : "Zakázať hovory",
    "Save changes" : "Uložiť zmeny",
    "Saving …" : "Ukladá sa...",
    "Saved!" : "Uložené!",
    "Limit to groups" : "Povoľ len pre skupiny",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Keď je vybratá aspoň jedna skupina, tak sa rozhovoru môžu zúčastniť len používatelia z uvedených skupín.",
    "Guests can still join public conversations." : "Hostia sa vždy môžu pripojiť k verejným rozhovorom.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Používatelia, ktorí už nemôžu používať službu Rozhovor, budú naďalej uvedení ako účastníci predchádzajúcich rozhovorov a aj ich správy v rozhovoroch budú zachované.",
    "Limit using Talk" : "Obmedziť používanie Rozhovoru",
    "Limit creating a public and group conversation" : "Obmedziť vytváranie verejných a skupinových rozhovorov",
    "Limit creating conversations" : "Obmedziť vytváranie rozhovorov",
    "Limit starting a call" : "Obmedziť začatie hovoru",
    "Limit starting calls" : "Obmedziť začatie hovorov",
    "When a call has started, everyone with access to the conversation can join the call." : "Po začatí hovoru sa k hovoru môžu pripojiť všetci, ktorí majú k nemu prístup.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Nasledujúce roboty sú nainštalované na tomto serveri. V dokumentácii nájdete podrobnosti o tom, ako {linkstart1}vytvoriť vlastného bota{linkend} alebo {linkstart2}zoznam robotov{linkend}, ktoré môžete povoliť na vašom serveri.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Žiadne boty nie sú nainštalované na tomto serveri. V dokumentácii nájdete podrobnosti o tom, ako {linkstart1}vytvoriť vlastného bota{linkend} alebo {linkstart2}zoznam robotov{linkend}, ktoré môžete povoliť na vašom serveri.",
    "Description is not provided" : "Popis nie je uvedený",
    "Locked for moderators" : "Zamknuté pre moderátorov",
    "Enabled" : "Zapnuté",
    "Disabled" : "Vypnuté",
    "Bots settings" : "Nastavenia botov",
    "State" : "Stav",
    "Name" : "Názov",
    "Last error" : "Posledná chyba",
    "Total errors count" : "Celkový počet chýb",
    "Find more bots" : "Nájsť viac botov",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Dôveryhodné servery je možné konfigurovať na {linkstart}stránke Nastavenia zdieľania{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Združené rozhovory a hovory už fungujú. Spracovanie príloh príde v budúcej verzii.",
    "Enable Federation in Talk app" : "Povoliť združovanie v aplikácii Talk /Rozhovor/",
    "Permissions" : "Oprávnenia",
    "Allow users to be invited to federated conversations" : "Povoliť užívateľom pozývať na združené konverzácie",
    "Allow users to invite federated users into conversation" : "Povoliť užívateľom pozývať federovaných užívateľov do konverzácií",
    "Only allow to federate with trusted servers" : "Povoliť iba federácie s dôveryhodnými servermi",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Keď je vybratá aspoň jedna skupina, tak sa rozhovoru môžu zúčastniť len užívatelia z uvedených skupín.",
    "Groups allowed to invite federated users" : "Skupiny oprávnené pozvať federovaných používateľov",
    "Select groups …" : "Vybrať skupinu ...",
    "All messages" : "Všetky správy",
    "@-mentions only" : "Iba zmienky v tvare @-meno",
    "Off" : "Vypnúť",
    "General settings" : "Všeobecné nastavenia",
    "Default notification settings" : "Predvolené nastavenia upozornení",
    "Default group notification" : "Predvolené upozornenia pre skupinu",
    "Default group notification for new groups" : "Predvolené upozornenia pre nové skupiny",
    "Integration into other apps" : "Napojenie na iné aplikácie",
    "Allow conversations on files" : "Povoliť konverzácie pri súboroch",
    "Allow conversations on public shares for files" : "Povoliť konverzácie pri verejných zdieľaniach súborov",
    "End-to-end encrypted calls" : "Koncové šifrovanie hovorov",
    "Enable encryption" : "Povoliť šifrovanie",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Šifrované hovory typu end-to-end s nakonfigurovaným mostom SIP vyžadujú novšiu verziu vysokovýkonného backendu a mosta SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobilní klienti momentálne nepodporujú end-to-end šifrované hovory",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Kliknutím na tlačidlo vyššie sa odošlú informácie z formulára na servery Struktur AG. Ďalšie informácie nájdete na stránke {linkstart}spreed.eu {linkend}.",
    "Pending" : "Prebieha",
    "Error" : "Chyba",
    "Blocked" : "Zablokovaný",
    "Active" : "Aktívne",
    "Expired" : "Platnosť skončila",
    "Never" : "Nikdy",
    "The trial could not be requested. Please try again later." : "Nemožno požiadať o skúšobnú verziu. Skúste to neskôr prosím.",
    "The account could not be deleted. Please try again later." : "Účet sa nepodarilo odstrániť. Skúste to neskôr prosím.",
    "Hosted High-performance backend" : "Hosťovaný vysokovýkonný backend",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Náš partner Struktur AG poskytuje službu, kde je možné požiadať o hosťovaný signalizačný server. Na tento účel stačí vyplniť nasledujúci formulár a Nextcloud o to požiada. Po nastavení servera sa prihlasovacie údaje vyplnia automaticky. Týmto sa prepíšu existujúce nastavenia signalizačného servera.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Ak váš účet pre backend s vysokým výkonom zahŕňa funkcie STUN a/alebo TURN, nastavenia budú aktualizované podľa toho.",
    "URL of this Nextcloud instance" : "URL tejto inštancie Nextcloudu",
    "Full name of the user requesting the trial" : "Úplné meno používateľa, ktorý žiada o skúšobnú verziu",
    "Email of the user" : "E-mail užívateľa",
    "Language" : "Jazyk",
    "Country" : "Krajina",
    "Request signaling server trial" : "Vyžiadať skúšobnú verziu signalizačného servera",
    "You can see the current status of your hosted signaling server in the following table." : "Aktuálny stav hosťovaného signalizačného servera môžete vidieť v nasledujúcej tabuľke.",
    "Status" : "Stav",
    "Created at" : "Vytvorené:",
    "Expires at" : "Platnosť končí",
    "Limits" : "Limity",
    "STUN included" : "STUN zahrnutý",
    "Yes" : "Áno",
    "No" : "Nie",
    "TURN included" : "TURN zahrnutý",
    "Delete the signaling server account" : "Odstrániť účet signalizačného servera",
    "_%n user_::_%n users_" : ["%n používateľ","%n používatelia","%n používatelia","%n používateľov"],
    "Installed version: {version}" : "Naištalovaná verzia: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Môžete si nainštalovať Matterbridge a prepojiť Nextcloud Talk /Rozhovor/ s niektorými ďalšími službami. Ďalšie podrobnosti nájdete na ich {linkstart1}stránke GitHub{linkend}. Stiahnutie a inštalácia aplikácie môže chvíľu trvať. V prípade, že uplynie časový limit, nainštalujte ho manuálne z {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Binárny súbor Matterbridge má nesprávne oprávnenia. Uistite sa, že binárny súbor Matterbridge patrí správnemu používateľovi a môže byť spustený. Nachádza sa v adresári \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Spustiteľný súbor Matterbridge nebol nájdený alebo nemohol byť spustený.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "V nastavení je možné ručne nastaviť cestu spustiteľného súboru Matterbridge. Podrobnosti nájdete v {linkstart}dokumentácii k napojeniu Matterbridge{linkend}.",
    "Downloading …" : "Sťahujem …",
    "Install Talk Matterbridge" : "Inštalovať Matterbridge pre Talk /Rozhovor/",
    "An error occurred while installing the Matterbridge app" : "Pri pokuse o inštaláciu Matterbridge sa vyskytla chyba",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Pri pokuse o inštaláciu Talk /Rozhovor/ Matterbridge sa vyskytla chyba. Inštalujte ju ručne, prosím.",
    "Failed to execute Matterbridge binary." : "Nepodarilo sa spustiť súbor Matterbridge.",
    "Matterbridge integration" : "Napojenie na Matterbridge",
    "Enable Matterbridge integration" : "Zapnúť napojenie na Matterbridge",
    "Status: Checking connection" : "Stav: Kontrola pripojenia",
    "OK: Running version: {version}" : "OK: Spustená verzia: {version}",
    "Error: Server seems to be a Signaling server" : "Chyba: Server sa zdá byť signalizačným serverom",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Chyba: Systémové časy servera Nextcloud a servera pre nahrávací backend nie sú synchronizované. Uistite sa, že sú oba servery pripojené k časovému serveru alebo manuálne synchronizujte ich čas.",
    "Recording backend URL" : "URL adresa backendu pre záznam",
    "Validate SSL certificate" : "Overiť SSL certifikát",
    "Delete this server" : "Zmazať server",
    "Test this server" : "Vyskúšť tento server",
    "Disabled for all calls" : "Zakázané pre všetky hovory",
    "Enabled for all calls" : "Povolené pre všetky hovory",
    "Configurable on conversation level by moderators" : "Konfigurovateľné na úrovni konverzácie moderátormi",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP nastavenia \"upload_max_filesize\" alebo \"post_max_size\" umožňujú  nahrávať súbory iba do veľkosti {maxUpload}.",
    "Recording backend settings saved" : "Nastavenia záznamového backendu boli uložené",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderátori budú môcť povoliť súhlas pre záznam na úrovni konverzácie. Súhlas, pre záznam, bude vyžadovaný pre každého účastníka pred pripojením sa k hovoru v tejto konverzácii.",
    "The consent to be recorded will be required for each participant before joining every call." : "Súhlas so záznamom bude vyžadovaný od každého účastníka pred pripojením sa ku každému hovoru.",
    "The consent to be recorded is not required." : "Súhlas so záznamom nie je potrebný.",
    "Recording backend configuration is only possible with a High-performance backend." : "Konfigurácia backendu nahrávania je možná len s vysokovýkonným backendom.",
    "Add a new recording backend server" : "Pridajte nový server pre záznamový backend",
    "Shared secret" : "Shared secret",
    "Recording consent" : "Súhlas so záznamom",
    "Recording transcription" : "Prepis nahrávky",
    "Automatically transcribe call recordings with a transcription provider" : "Automaticky prepisujte nahrávky hovorov pomocou poskytovateľa prepisov",
    "Automatically summarize call recordings with transcription and summary providers" : "Automaticky zhrnúť nahrávky hovorov s poskytovateľmi prepisu a súhrnu",
    "SIP configuration saved!" : "Nastavenie SIP bolo uložené!",
    "SIP configuration is only possible with a High-performance backend." : "Konfigurácia SIP je možná len s vysokovýkonným backendom.",
    "Enable SIP Dial-out option" : "Povoliť možnosť SIP Dial-out",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signálny server musí byť aktualizovaný, aby podporoval funkcie SIP Dial-out.",
    "Do not show SIP Dial-out caller number" : "Nezobrazovať číslo volajúceho pri volaní cez SIP.",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Anonymné číslo by malo byť zobrazené ako \"neznáme\" alebo \"zablokované číslo\" pre príjemcu hovoru",
    "Dial-out number" : "Číslo na vytočenie",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Číslo v formáte E164 používané ako náhradné číslo volajúceho pre odchádzajúce hovory",
    "Dial-out prefix" : "Predvoľba na vytočenie",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Predpona k nakonfigurovanému číslu používateľa pre odchádzajúce hovory (predvolené je `+`)",
    "Restrict SIP configuration" : "Obmedziť nastavenie SIP",
    "Enable SIP configuration" : "Zapnúť nastavenie SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Iba používatelia nasledujúcich skupín môžu povoliť SIP v konverzáciách, ktoré moderujú",
    "Phone number (Country)" : "Telefónne číslo (Štát)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Tieto informácie sa odosielajú v pozývacích e-mailoch a tiež sa zobrazujú na bočnom paneli všetkým účastníkom.",
    "Nextcloud base URL" : "Základná URL Nextcloud",
    "Talk Backend URL" : "Backend URL aplikácie Talk",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "Dostupné funkcie",
    "Error: Websocket connection failed" : "Chyba: Zlyhalo pripojenie cez Websocket",
    "Error code" : "Chybový kód",
    "Error message" : "Chybové hlásenie",
    "Error: Websocket connection failed. Check browser console" : "Chyba: Pripojenie cez Websocket zlyhalo. Skontrolujte konzolu prehliadača",
    "High-performance backend URL" : "URL vysoko výkonnej podpornej vrstvy",
    "Missing High-performance backend warning hidden" : "Upozornenie na chýbajúci backend s vysokým výkonom je skryté",
    "High-performance backend settings saved" : "Nastavenia vysokovýkonného backendu boli uložené",
    "Nextcloud Talk setup not complete" : "Nastavenie Nextcloud Talk nie je kompletné",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Upozorňujeme, že pri hovoroch s viac ako 2 účastníkmi bez vysokovýkonného backendu sa u účastníkov s najväčšou pravdepodobnosťou vyskytnú problémy s pripojením a spôsobia vysoké zaťaženie zúčastnených zariadení.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nainštalujte si vysokovýkonný backend, aby ste zabezpečili bezproblémové fungovanie hovorov s viacerými účastníkmi.",
    "Nextcloud portal" : "Portál Nextcloud",
    "Quick installation guide" : "Rýchla inštalačná príručka",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Pre hovory a konverzácie s viacerými účastníkmi je potrebný vysokovýkonný backend. Bez backendu musia všetci účastníci nahrávať svoje vlastné video jednotlivo pre každého iného účastníka, čo s najväčšou pravdepodobnosťou spôsobí problémy s pripojením a vysoké zaťaženie zúčastnených zariadení.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Pri používaní Nextcloud Talk s vysokovýkonným backendom sa dôrazne odporúča nastaviť distribuovanú vyrovnávaciu pamäť.",
    "Add High-performance backend server" : "Pridať vysoko výkonný backend server",
    "Warn about connectivity issues in calls with more than 2 participants" : "Upozorniť na problémy s pripojením pri hovoroch s viac ako 2 účastníkmi",
    "STUN server URL" : "URL STUN servera",
    "The server address is invalid" : "Adresa servera je neplatná",
    "STUN settings saved" : "Nastavenia STUN boli uložené",
    "STUN servers" : "STUN server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN server je používaný na zistenie verejnej IP adresy účastníkov za smerovačom.",
    "Add a new STUN server" : "Pridať nový STUN server",
    "{schema} scheme must be used with a domain" : "Schéma {schema} sa musí používať s doménou",
    "{option1} and {option2}" : "{option1} a {option2}",
    "{option} only" : "iba {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: TURN server vrátil úspešných ICE kandidátov",
    "Error: No working ICE candidates returned by the TURN server" : "Chyba: TURN server nevrátil žiadnych funkčných ICE kandidátov",
    "Testing whether the TURN server returns ICE candidates" : "Zisťuje sa, či server TURN vracia ICE kandidátov",
    "TURN server schemes" : "Popis TURN serveru",
    "TURN server URL" : "URL TURN servera",
    "TURN server secret" : "Kód pre TURN server",
    "TURN server protocols" : "Protokoly servera TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN server slúži ako proxy pre prenos od účastníkov, ktorí sú za bránou firewall. Ak sa jednotliví účastníci nemôžu spojiť s ostatnými, najskor je potrebný TURN server. Pokyny na nastavenie nájdete v {linkstart}tejto dokumentácii{linkend}.",
    "TURN settings saved" : "Nastavenia TURN boli uložené",
    "TURN servers" : "TURN servery",
    "Add a new TURN server" : "Pridať nový TURN server",
    "Failed" : "Zlyhalo",
    "OK" : "OK",
    "Checking …" : "Kontrolujem ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Zlyhalo: WebAssembly je v tomto prehliadači zakázané alebo nie je podporované. Povoľte WebAssembly alebo použite prehliadač s podporou na vykonanie kontroly.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Zlyhalo: Webový server správne nevrátil súbory „.wasm“ a „.tflite“. Skontrolujte časť „Systémové požiadavky“ v dokumentácii Talk /Rozhovor/.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: Webový server správne vrátil súbory „.wasm“ a „.tflite“.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Zdá sa, že konfigurácia PHP a Apache nie je kompatibilná. Upozorňujeme, že PHP je možné použiť iba s modulom MPM_PREFORK a PHP-FPM je možné použiť iba s modulom MPM_EVENT.",
    "Web server setup checks" : "Kontroly nastavenia webového servera",
    "Files required for virtual background can be loaded" : "Súbory potrebné pre virtuálne pozadie môžu byť nahrané",
    "Federated user" : "Združený užívateľ",
    "Assign participants to rooms" : "Priraďte účastníkov do miestností",
    "Configure breakout rooms" : "Nastaviť vyhradené miestnosti",
    "Number of breakout rooms" : "Počet vyhradených miestností",
    "You can create from 1 to 20 breakout rooms." : "Môžete vytvoriť od 1 do 20 odpočinkových miestností.",
    "Assignment method" : "Spôsob rozdelenia do skupín",
    "Automatically assign participants" : "Automaticky rozdeliť účastníkov",
    "Manually assign participants" : "Manuálne rozdeliť účastníkov",
    "Allow participants to choose" : "Dovoľte účastníkom vybrať si",
    "Create rooms" : "Vytvoriť miestnosti",
    "Confirm" : "Potvrdiť",
    "Create breakout rooms" : "Vytvoriť vyhradené miestnosti",
    "Reset" : "Resetovať",
    "Delete breakout rooms" : "Odstrániť vyhradené miestnosti",
    "Room {roomNumber}" : "Miestnosť {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Aktuálne odpočinkové miestnosti a nastavenia sa stratia",
    "Cancel" : "Zrušiť",
    "Unassigned participants" : "Nepripradení účastníci",
    "Back" : "Späť",
    "Assign" : "Priradiť",
    "Add participant \"{user}\"" : "Pridať účastníka \"{user}\"",
    "Now" : "Teraz",
    "Invalid calendar selected" : "Bol vybraný neplatný kalendár",
    "Invalid start time selected" : "Bol vybraný neplatný čas začiatku",
    "Invalid end time selected" : "Bol vybraný neplatný čas konca",
    "Unknown error occurred" : "Nastala neznáma chyba",
    "Sending no invitations" : "Neposielajú sa žiadne upozornenia",
    "{participant0} will receive an invitation" : "{participant0} dostane pozvánku",
    "{participant0} and {participant1} will receive invitations" : "{participant0} a {participant1} dostanú pozvánku",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} a %n ostatní dostanú pozvania","{participant0}, {participant1} a %n ostatní dostanú pozvania","{participant0}, {participant1} a %n ostatní dostanú pozvania","{participant0}, {participant1} a %n ostatní dostanú pozvania"],
    "Invite {user}" : "Pozvať {user}",
    "Invite all users and emails in this conversation" : "Pozvite všetkých používateľov a e-maily v tejto konverzácii.",
    "Meeting created" : "Stretnutie vytvorené",
    "Upcoming meetings" : "Nadchádzajúce stretnutia",
    "Loading …" : "Načítavam …",
    "No upcoming meetings" : "Žiadne nadchádzajúce stretnutia",
    "Schedule a meeting" : "Naplánovať stretnutie",
    "Meeting title" : "Názov stretnutia",
    "From" : "Od",
    "To" : "Pre",
    "Calendar" : "Kalendár",
    "Attendees" : "Účastníci",
    "No other participants to send invitations to." : "Nie sú žiadni ďalší účastníci, ktorým by bolo možné poslať pozvánky.",
    "Add attendees" : "Pridať účastníkov",
    "Save" : "Uložiť",
    "Search participants" : "Vyhľadať účastníkov",
    "No results" : "Žiadne výsledky",
    "Done" : "Hotovo",
    "Disable live transcription" : "Zakázať živý prepis",
    "Enable live transcription (generated by AI)" : "Povoliť živý prepis (generovaný AI)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Povoliť živý prepis (Aplikácia Live transcriptions nie je nainštalovaná)",
    "Disable live translation" : "Vypnúť živý preklad",
    "Enable live translation (generated by AI)" : "Povoliť živý preklad (generovaný AI)",
    "Original language" : "Pôvodný jazyk",
    "Live translations app is not installed" : "Aplikácia pre živé preklady nie je nainštalovaná",
    "Original language: {languageName}" : "Pôvodný jazyk: {languageName}",
    "Translated language" : "Jazyk prekladu",
    "Translated language: {languageName}" : "Jazyk prekladu: {languageName}",
    "Raise hand" : "Zdvihnúť ruku",
    "Raise hand (R)" : "Zdvihnúť ruku (R)",
    "Lower hand" : "Dať ruku dole",
    "Lower hand (R)" : "Dať ruku dole (R)",
    "Exit full screen (F)" : "Ukončiť režim celej obrazovky (F)",
    "Full screen (F)" : "Na celú obrazovku (F)",
    "Speaker view" : "Zobrazenie rečníka",
    "Grid view" : "Zobrazenie v mriežke",
    "Error when trying to load the available live transcription languages" : "Chyba pri pokuse o načítanie dostupných jazykov pre živý prepis",
    "Failed to enable live transcription" : "Nepodarilo sa povoliť živý prepis",
    "Failed to enable live translations" : "Nepodarilo sa povoliť živé preklady",
    "Failed to disable live translations" : "Nepodarilo sa vypnúť živé preklady",
    "Recording consent is required" : "Vyžaduje sa súhlas so zaznamenávaním",
    "This conversation is read-only" : "Táto konverzácia je iba na čítanie",
    "Conversation not found or not joined" : "Konverzácia nebola nájdená alebo nebola pripojená",
    "Lobby is still active and you're not a moderator" : "Čakáreň je stále aktívna a nie si moderátor.",
    "Connection failed" : "Pripojenie zlyhalo",
    "Reload" : "Znovu načítať",
    "{nickName} raised their hand." : "{nickName} zdvihol ruku.",
    "A participant raised their hand." : "Účastník zdvihol ruku.",
    "Collapse stripe" : "Zbaliť pruh",
    "Expand stripe" : "Rozbaliť pruh",
    "Previous page of videos" : "Predchodzia stránka videí",
    "Next page of videos" : "Ďalšia stránka videí",
    "Connecting …" : "Pripájam sa...",
    "Calling …" : "Volám ...",
    "Waiting for {user} to join the call" : "Čaká sa, kým sa k rozhovoru pripojí {user}",
    "Waiting for others to join the call …" : "Čaká sa na ostatných kým sa pripoja na hovor ...",
    "You can invite others in the participant tab of the sidebar" : "Ostatných môžete pozvať v záložke účastníkov v bočnom paneli",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Ostatných môžete pozvať v záložke účastníkov v bočnom paneli, alebo zdieľajte odkaz pre pozvanie iných.",
    "Share this link to invite others!" : "Zdieľajte tento odkaz na pozvanie ostatných!",
    "Copy link" : "Kopírovať odkaz",
    "You are not allowed to enable audio" : "Nemáte oprávnenie povoliť zvuk",
    "No audio. Click to select device" : "Žiadny zvuk. Kliknite pre výber zariadenia",
    "Mute audio" : "Vypnúť zvuk",
    "Mute audio (M)" : "Stlmiť zvuk (M)",
    "Unmute audio" : "Obnoviť zvuk",
    "Unmute audio (M)" : "Zapnúť zvuk (M)",
    "None" : "Žiadne",
    "Select a microphone" : "Vybrať mikrofón",
    "Select a speaker" : "Vybrať reproduktor",
    "Microphone settings" : "Nastavenia mikrofónu",
    "Check devices" : "Skontrolovať zariadenia",
    "Access to camera was denied" : "Prístup ku kamere bol zamietnutý",
    "Error while accessing camera: It is likely in use by another program" : "Chyba pri prístupe ku kamere: pravdepodobne ju používa iný program",
    "Error while accessing camera" : "Nastala chyba pri prístupe ku kamere",
    "You have been muted by a moderator" : "Stlmil vás moderator",
    "Hide presenter video" : "Skyť video moderátora",
    "You are not allowed to enable video" : "Nemáte oprávnenie povoliť video",
    "No video. Click to select device" : "Žiadne video. Kliknite pre výber zariadenia",
    "Disable video" : "Zakázať video",
    "Disable video (V)" : "Vypnúť video (V)",
    "Enable video" : "Zapnúť video",
    "Enable video (V)" : "Povoliť video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Zapnúť video. Vaše pripojenie bude pri prvom zapnutí videa krátko prerušené",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Povoliť video (V) - Pri prvom povolení videa sa vaše pripojenie na chvíľu preruší",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Zapnúť video. Vaše pripojenie bude pri prvom zapnutí videa krátko prerušené",
    "Select a video device" : "Vybrať video zariadenie",
    "Show presenter" : "Zobraziť prezentujúceho",
    "You" : "Vy",
    "Mute" : "Stlmiť",
    "Muted" : "Stlmené",
    "Show screen" : "Ukázať obrazovku",
    "Stop following" : "Prestať sledovať",
    "Connection could not be established …" : "Nie je možné sa pripojiť ...",
    "Connection was lost and could not be re-established …" : "Pripojenie sa prerušilo a nemôže byť obnovené ...",
    "Connection could not be established. Trying again …" : "Nie je možné sa pripojiť. Skúšam znova ...",
    "Connection lost. Trying to reconnect …" : "Pripojenie sa prerušilo. Skúšam sa pripojiť znova ...",
    "Connection problems …" : "Problémy s pripojením ...",
    "Collapse" : "Zvinúť",
    "Expand" : "Rozbaliť",
    "You need to be logged in to upload files" : "Pre nahrávenie súborov musíte byť prihlásený",
    "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
    "Conversation messages" : "Správy konverzácie",
    "Scroll to bottom" : "Posuňte sa nadol",
    "Post message" : "Uverejniť správu",
    "Federated conversation" : "Federovaný rozhovor",
    "Public conversation" : "Verejný rozhovor",
    "Favorite" : "Obľúbené",
    "Banned users" : "Zakázaný užívatelia",
    "Manage the list of banned users in this conversation." : "Spravovať zoznam zakázaných uživateľov v tejto konverzácii.",
    "Manage bans" : "Spravovať zákazy",
    "No banned users" : "Žiadny zakázaný uživatelia",
    "Banned by:" : "Zakazané od:",
    "Date:" : "Dátum:",
    "Note:" : "Poznámka:",
    "Hide details" : "Skryť podrobnosti",
    "Show details" : "Zobraziť podrobnosti",
    "Unban" : "Zrušiť zákaz",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Môžete zmeniť názov a popis v {linkstart} Kalendári ↗ {linkend}.",
    "Error while updating conversation name" : "Chyba pri aktualizácii názvu konverzácie",
    "Error while updating conversation description" : "Chyba pri úprave popisu konverzácie",
    "Enter a name for this conversation" : "Zadajte názov pre túto konverzáciu",
    "Edit conversation name" : "Upraviť názov konverzácie",
    "Edit conversation description" : "Upraviť popis konverzácie",
    "Enter a description for this conversation" : "Vložte popis tejto konverzácie",
    "Picture" : "Obrázok",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Nasledujúce boty môžu byť povolené v tejto konverzácii. Obráťte sa na svoju administráciu, aby ste získali ďalšie boty nainštalované na tomto serveri.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Žiadne roboty nie sú nainštalované na tomto serveri. Obráťte sa na svoju administráciu, aby ste získali zoznam robotov na tomto serveri.",
    "Disable" : "Zakázať",
    "Enable" : "Povoliť",
    "The bot is not available anymore" : "Bot už nie je k dispozícii",
    "Breakout rooms" : "Vyhradené miestnosti",
    "Manage breakout rooms" : "Spravovať vyhradené miestnosti",
    "Set up breakout rooms for this conversation" : "Nastaviť vyhradené miestnosti pre túto konverzáciu",
    "Please select a valid PNG or JPG file" : "Prosím vyberte platný PNG alebo JPG súbor",
    "Choose your conversation picture" : "Vyberte obrázok konverzácie",
    "Choose" : "Vybrať",
    "Error setting conversation picture" : "Chyba pri nastavovaní obrázka konverzácie",
    "Could not set the conversation picture: {error}" : "Nepodarilo sa nastaviť obrázok konverzácie: {error}",
    "Error cropping conversation picture" : "Chyba pri orezávaní obrázka konverzácie",
    "Error removing conversation picture" : "Chyba pri odstraňovaní obrázka konverzácie",
    "Set emoji as conversation picture" : "Nastavte emotikon ako obrázok konverzácie",
    "Set background color for conversation picture" : "Nastavte farbu pozadia pre obrázok konverzácie",
    "Upload conversation picture" : "Nahrať obrázok konverzácie",
    "Choose conversation picture from files" : "Vyberte obrázok konverzácie zo súborov",
    "Remove conversation picture" : "Odstrániť obrázok konverzácie",
    "The file must be a PNG or JPG" : "Súbor musí byť vo formáte PNG alebo JPG",
    "Set picture" : "Nastaviť obrázok",
    "Default permissions modified for {conversationName}" : "Predvolené oprávnenia pre {conversationName} boli upravené",
    "Could not modify default permissions for {conversationName}" : "Nie je možné upraviť oprávnenia pre {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Upravte predvolené práva pre účastníkov tejto konverzácie. Tieto nastavenia neovplyvňujú moderátorov.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Zakaždým, keď sa v tejto sekcii upravia oprávnenia, vlastné oprávnenia, ktoré boli predtým pridelené jednotlivým účastníkom, sa stratia.",
    "All permissions" : "Všetky oprávnenia",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Účastníci majú oprávnenia začať hovor, pripojiť sa k hovoru, povoliť zvuk, video a zdieľanie obrazovky.",
    "Restricted" : "Obmedzené",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Účastníci sa môžu pripojiť k hovorom, ale nemôžu povoliť zvuk, video alebo zdieľanie obrazovky, kým im moderátor manuálne neudelí oprávnenia.",
    "Advanced permissions" : "Rozšírené oprávnenia",
    "Edit permissions" : "Upraviť oprávnenia",
    "Conversation settings" : "Nastavenia konverzácie",
    "Basic Info" : "Základné informácie",
    "Personal" : "Osobné",
    "Moderation" : "Moderovanie",
    "Setup overview" : "Prehľad nastavenia",
    "Live transcription" : "Živý prepis",
    "Live transcriptions app is not installed" : "Aplikácia pre živé prepisy nie je nainštalovaná",
    "Enable live transcription" : "Povoliť živý prepis",
    "Breakout Rooms" : "Vyhradené miestnosti",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Boty",
    "Danger zone" : "Nebezpečná oblasť",
    "Archive conversation" : "Archivovať konverzáciu",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Archivované konverzácie sú predvolene skryté v zozname konverzácií. Stále sa však zobrazia, keď vyhľadáte názov konverzácie alebo pristupujete k zoznamu archivovaných konverzácií.",
    "Do you really want to leave \"{displayName}\"?" : "Naozaj chcete opustiť \"{displayName}\"?",
    "You can archive this conversation instead." : "Môžete túto konverzáciu namiesto toho archivovať.",
    "Leave conversation" : "Opustiť konverzáciu",
    "You need to promote a new moderator before you can leave the conversation" : "Skôr než budete môcť opustiť rozhovor, je potrebné niekomu odovzdať rolu moderátora.",
    "Delete conversation" : "Odstrániť konverzáciu",
    "Do you really want to delete \"{displayName}\"?" : "Naozaj chcete odstrániť „{displayName}“?",
    "Error while deleting conversation" : "Chyba pri vymazávaní konverzácie",
    "Delete all chat messages" : "Vymazať všetky správy v rozhovore",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Naozaj chcete odstrániť všetky správy v priečinku „{displayName}“?",
    "Error while clearing chat history" : "Chyba pri čistení histórie rozhovoru",
    "Be careful, these actions cannot be undone." : "Buďte obozretný, táto akcia sa nedá vrátiť späť.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Keď je konverzácia opustená, na opätovné zapojenie do uzavretej konverzácie je potrebné pozvánka. K otvorenej konverzácii sa môžete pripojiť kedykoľvek.",
    "Permanently delete this conversation." : "Natrvalo odstrániť túto konverzáciu.",
    "Delete chat messages" : "Vymazať správy z rozhovoru",
    "Permanently delete all the messages in this conversation." : "Natrvalo odstrániť všetky správy v tejto konverzácii.",
    "_%n hour_::_%n hours_" : ["%n hodina","%n hodiny","%n hodín","%n hodiny"],
    "_%n day_::_%n days_" : ["%n deň","%n dni","%n dní","%n dni"],
    "_%n week_::_%n weeks_" : ["%n týždeň","%n týždne","%n týždňov","%n týždne"],
    "Custom expiration time" : "Vlastný čas vypršania platnosti správy",
    "Message expiration disabled" : "Vypršanie platnosti správy je vypnuté",
    "Message expiration set: {duration}" : "Vypršanie platnosti správy nastavené na: {duration}",
    "Error when trying to set message expiration" : "Chyba pri pokuse o nastavenie uplynutia platnosti správy",
    "Message expiration" : "Vypršanie platnosti správy",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Platnosť četových správ môže po určitom čase vypršať. Poznámka: Súbory zdieľané v chate sa vlastníkovi neodstránia, ale už sa nebudú zdieľať v konverzácii.",
    "Set message expiration" : "Nastaviť platnosť správ",
    "Current message expiration" : "Súčasná expirácia správ",
    "Password copied to clipboard" : "Heslo bolo skopírované do schránky",
    "Password could not be copied" : "Heslo sa nepodarilo skopírovať.",
    "Guest access" : "Prístup pre hostí",
    "Breakout rooms are not allowed in public conversations." : "Oddelené miestnosti nie sú povolené v verejných rozhovoroch.",
    "Allow guests to join this conversation via link" : "Umožniť hosťom pripojiť sa k rozhovoru prostredníctvom odkazu",
    "Password protection" : "Ochrana heslom",
    "This conversation is password-protected. Guests need password to join" : "Táto konverzácia je chránená heslom. Hostia potrebujú heslo na pripojenie.",
    "Password protection is needed for public conversations" : "Ochrana heslom je potrebná pre verejné konverzácie.",
    "Set a password" : "Nastavte si heslo",
    "Change password" : "Zmeniť heslo",
    "Enter new password" : "Zadať nové heslo",
    "Save password" : "Uložiť heslo",
    "Copy password" : "Kopírovať heslo",
    "Guests are allowed to join this conversation via link" : "Hostia majú povolené pripojiť sa k tejto konverzácii cez odkaz",
    "Guests are not allowed to join this conversation" : "Hostia nemajú povolené pridať sa k tejto konverzácii",
    "Resend invitations" : "Znovy odslať pozvánky",
    "This conversation is open to both registered users and users created with the Guests app" : "Táto konverzácia je otvorená pre registrovaných užívateľov aj pre užívateľov vytvorených pomocou aplikácie Guests.",
    "This conversation is open to registered users" : "Táto konverzácia je otvorená pre registrovaných užívateľov",
    "This conversation is limited to the current participants" : "Táto konverzácia je obmedzená na súčasných účastníkov",
    "You opened the conversation to both registered users and users created with the Guests app" : "Otvorili ste konverzáciu pre registrovaných užívateľov a užívateľov vytvorených pomocou aplikácie Guests",
    "Error occurred when opening or limiting the conversation" : "Pri otváraní alebo obmedzovaní konverzácie nastala chyba",
    "Open conversation to registered users, showing it in search results" : "Otvoriť konverzáciu pre registrovaných užívateľov a zobraziť ju vo výsledkoch vyhľadávania",
    "Also open to users created with the Guests app" : "Taktiež otvorené pre užívateľov vytvorených pomocou aplikácie Guests",
    "Open conversation" : "Otvoriť konverzáciu",
    "Set language spoken in calls" : "Nastaviť jazyk používaný počas hovorov",
    "Languages could not be loaded" : "Jazyky sa nedali načítať",
    "Loading languages …" : "Načítavanie jazykov …",
    "Invalid language" : "Neplatný jazyk",
    "Default language (English)" : "Predvolený jazyk (angličtina)",
    "Default live transcription language set" : "Predvolený jazyk živého prepisu nastavený",
    "Live transcription language set: {languageName}" : "Jazyk živého prepisu nastavený na: {languageName}",
    "Error when trying to set live transcription language" : "Chyba pri pokuse o nastavenie jazyka živého prepisu",
    "Start time: {date}" : "Čas začiatku: {date}",
    "Start time has been updated" : "Čas začiatku bol zmenený",
    "Error occurred while updating start time" : "Pri nastavovaní času začiatku sa vyskytla chyba",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Zapnutie čakárne odstráni nemoderátorov z prebiehajúceho hovoru.",
    "Enable lobby, restricting the conversation to moderators" : "Povoliť čakáreň, obmedziť konverzáciu iba na moderátorov",
    "Meeting start time" : "Čas začatia schôdzky",
    "Start time (optional)" : "Čas začiatku (voliteľné)",
    "Import email participants" : "Importovať účastníkov e-mailu",
    "You can import a list of email participants from a CSV file." : "Môžete importovať zoznam účastníkov e-mailu zo súboru CSV.",
    "Poll drafts" : "Návrhy ankiet",
    "Browse poll drafts" : "Prehľadávať návrhy ankiet",
    "Error occurred when locking the conversation" : "Pri zamykaní konverzácie nastala chyba",
    "Error occurred when unlocking the conversation" : "Pri odomykaní konverzácie nastala chyba",
    "Lock conversation" : "Zamknúť konverzáciu",
    "This will also terminate the ongoing call." : "Týmto sa ukončí aj prebiehajúci hovor.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Uzamknite konverzáciu, aby ste zabránili komukoľvek uverejňovať správy alebo začínať hovory",
    "Edit" : "Upraviť",
    "More information" : "Viac informácií",
    "Delete" : "Zmazať",
    "Add new bridged channel to current conversation" : "Pridajte do aktuálnej konverzácie nový premosťovací kanál",
    "unknown state" : "neznámy stav",
    "running" : "spustené",
    "not running, check Matterbridge log" : "nebeží, skontrolujte Matterbridge log",
    "not running" : "nespustené",
    "Bridge saved" : "Premostenie uložené",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Pomocou Matterbridge môžete premosťovať kanály z rôznych systémov okamžitých správ.",
    "More info on Matterbridge" : "Viac informácií o Matterbridge",
    "Messaging systems" : "Systémy posielania správ",
    "Enable bridge" : "Povoliť most",
    "Show Matterbridge log" : "Zobraziť záznam udalostí Matterbridge",
    "Log content" : "Obsah logov",
    "Only moderators are allowed to mention @all" : "Iba moderátori smú spomínať @all",
    "All participants are allowed to mention @all" : "Všetkým účastníkom je povolené spomenúť @all.",
    "Participants are now allowed to mention @all." : "Účastníci môžu teraz spomínať @all.",
    "Mentioning @all has been limited to moderators." : "Zmienka o @all bola obmedzená na moderátorov.",
    "Allow participants to mention @all" : "Dovoliť účastníkom spomenúť @all (všetkých)",
    "Mention permissions" : "Oprávnenia pre zmienku",
    "Notifications" : "Upozornenia",
    "Notify about calls in this conversation" : "Upozorniť na hovory v tejto konverzácii",
    "Important conversation" : "Dôležitá konverzácia",
    "\"Do not disturb\" user status is ignored for important conversations" : "Stav používateľa „Nerušiť“ sa pri dôležitých konverzáciách ignoruje.",
    "Sensitive conversation" : "Citlivá konverzácia",
    "Message preview will be disabled in conversation list and notifications" : "Ukážka správy bude v zozname konverzácií a v upozorneniach vypnutá",
    "Recording consent is required for calls in this conversation" : "Súhlas so záznamom je potrebný pre hovory v tejto konverzácii",
    "Recording consent is not required for calls in this conversation" : "Súhlas so záznamom nie je potrebný pre hovory v tejto konverzácii",
    "Recording consent requirement was updated" : "Požiadavka o súhlas so záznamom bola aktualizovaná.",
    "Error occurred while updating recording consent" : "Pri aktualizácii súhlasu so záznamom sa vyskytla chyba",
    "Recording Consent" : "Súhlas so záznamom",
    "Recording consent cannot be changed once a call or breakout session has started." : "Súhlas s nahrávaním nemôže byť zmenený, akonáhle sa začne hovor alebo odpočinková relácia.",
    "Require recording consent before joining call in this conversation" : "Vyžadovať súhlas so záznamom pred pripojením hovoru v tejto konverzácii",
    "Recording consent is required for all calls" : "Súhlas so záznamom je potrebný pre všetky hovory",
    "SIP dial-in is now possible without PIN requirement" : "SIP telefonické pripojenie je teraz možné bez požiadavky na PIN",
    "SIP dial-in is now enabled" : "SIP prijatie hovoru je teraz zapnuté",
    "SIP dial-in is now disabled" : "SIP prijatie hovoru je teraz vypnuté",
    "Error occurred when enabling SIP dial-in" : "Nastala chyba pri povoľovaní prijatia hovoru cez SIP",
    "Error occurred when disabling SIP dial-in" : "Nastala chyba pri vypínaní prijatia hovoru cez SIP",
    "Phone and SIP dial-in" : "Vytáčanie telefónom a SIP ",
    "Enable phone and SIP dial-in" : "Povoliť vytáčanie telefónom a SIP ",
    "Allow to dial-in without a PIN" : "Povoliť vytáčanie bez pin-u",
    "Ongoing" : "Prebieha",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n osoba prijala","%n ľudí prijalo","%n ľudí prijalo","%n ľudí prijalo"],
    "_%n person declined_::_%n people declined_" : ["%n osoba odmietla","%n ľudí odmietlo","%n ľudí odmietlo","%n ľudia odmietli"],
    "_and %n other attachment_::_and %n other attachments_" : ["a %n iná príloha","a %n iných príloh","a %n iných príloh","a %n iných príloh"],
    "With {displayName}" : "S {displayName}",
    "In {conversation}" : "V {conversation}",
    "View attachment" : "Zobraziť prílohu",
    "Join" : "Pripojiť",
    "View conversation" : "Zobraziť konverzáciu",
    "View event on Calendar" : "Zobraziť udalosť v kalendári",
    "Error while creating the conversation" : "Pri vytváraní konverzácie sa vyskytla chyba",
    "Hello, {displayName}" : "Ahoj, {displayName}",
    "Start meeting now" : "Začať stretnutie teraz",
    "Give your meeting a title" : "Dajte svojej schôdzke názov",
    "Create and copy link" : "Vytvoriť a skopírovať odkaz",
    "Create a new conversation" : "Vytvoriť novú konverzáciu",
    "Join open conversations" : "Pripojiť sa k prebiehajúcim konverzáciam",
    "Call a phone number" : "Zavolať na telefónne číslo",
    "Scroll backward" : "Prejsť späť",
    "Scroll forward" : "Posunúť dopredu",
    "Schedule meetings" : "Plánovať stretnutia",
    "You don't have any upcoming meetings" : "Nemáte žiadne nadchádzajúce stretnutia",
    "Open calendar" : "Otvoriť kalendár",
    "Unread mentions" : "Neprečítané upozornenia",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Správy, v ktorých ste boli spomenutí, sa tu zobrazia. Ľudí môžete spomenúť tak, že napíšete @ nasledované ich menom.",
    "Upcoming reminders" : "Nadchádzajúce pripomienky",
    "Message reminders" : "Pripomienky správ",
    "Set a reminder on a message to be notified" : "Pre upozornenie nastavte pripomienku na správu",
    "Start a group conversation" : "Začnite skupinovú konverzáciu",
    "Create conversation" : "Vytvoriť konverzáciu",
    "Enter your name" : "Zadajte svoje meno",
    "Submit name and join" : "Odoslať meno a pripojiť sa",
    "Do you already have an account?" : "Už máte účeť?",
    "Log in" : "Prihlásiť sa",
    "Error while verifying uploaded file" : "Chyba pri overovaní nahraného súboru",
    "Uploaded file is verified" : "Nahraný súbor je overený",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Formát obsahu je hodnoty oddelené čiarkami (CSV):<br/>- Hlavičkový riadok je povinný a musí zodpovedať <samp>\"meno\",\"email\"</samp> alebo len <samp>\"email\"</samp><br/>- Jeden záznam na riadok (napr. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Účastníci boli úspešne pridaní",
    "Error while adding participants" : "Chyba pri pridávaní účastníkov",
    "Import a file" : "Importovať súbor",
    "Browse" : "Prechádzať",
    "Verifying uploaded file …" : "Overovanie nahraného súboru ...",
    "This might take a moment" : "Toto môže chvíľu trvať.",
    "Send invitations" : "Odoslať pozvánky",
    "_%n invalid email_::_%n invalid emails_" : ["%n neplatný email","%n neplatné emaily","%n neplatných emailov","%n neplatných emailov"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-mail je už importovaný alebo je duplikát","%n e-mailov sú už importované alebo sú duplikáty","%n e-mailov sú už importované alebo sú duplikáty","%n e-maily sú už importované alebo sú duplikáty"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n pozvánka môže byť odoslaná","%n pozvánky môžu byť odoslané","%n pozvánok môže byť odoslaných","%n pozvánok môže byť odoslaných"],
    "An error occurred while calling a phone number" : "Pri volaní na telefónne číslo sa vyskytla chyba",
    "Phone number could not be called: {error}" : "Telefónne číslo sa nedalo zavolať: {error}",
    "Phone number could not be called" : "Telefónne číslo sa nedalo zavolať",
    "Search participants or phone numbers" : "Hľadať účastníkov alebo telefónne čísla",
    "Creating the conversation …" : "Vytváram konverzáciu ...",
    "Mark as read" : "Označiť ako prečítané",
    "Mark as unread" : "Označiť ako neprečítané",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "Unarchive conversation" : "Zrušiť archiváciu konverzácie",
    "Ignore \"Do not disturb\"" : "Ignorovať \"Nevyrušovať\"",
    "You need to promote a new moderator before you can leave the conversation." : "Skôr než budete môcť opustiť rozhovor, je potrebné niekomu odovzdať rolu moderátora.",
    "Conversation actions" : "Akcie konverzácie",
    "Notify about calls" : "Upozorniť na hovory",
    "Hide message text" : "Skryť text správy",
    "Pending invitations" : "Čakajúce pozvánky",
    "Join conversations from other servers" : "Pripojte sa k rozhovorom z iných serverov",
    "From {user} at {remoteServer}" : "Od {user} na {remoteServer}",
    "Decline invitation" : "Odmietnuť pozvánku",
    "Accept invitation" : "Prijať pozvánku",
    "No pending invitations" : "Žiadne čakajúce pozvánky",
    "Home" : "Domov",
    "Unread" : "Neprečítané",
    "Mentions" : "Zmienky",
    "Meetings" : "Stretnutia",
    "Sort conversations" : "Zoradiť konverzácie",
    "By recent activity" : "Podľa nedávnej aktivity",
    "Alphabetically" : "Abecedne",
    "Do not group by type" : "Nezoskupovať podľa typu",
    "Show private ones first" : "Najprv zobraz súkromné položky",
    "Show group ones first" : "Zobraziť najprv skupiny",
    "No followed threads" : "Žiadne sledované vlákna",
    "No matches found" : "Nebola nájdená žiadna zhoda",
    "No conversations found" : "Neboli nájdené žiadne konverzácie",
    "You have no archived conversations." : "Nemáte žiadne archivované konverzácie",
    "Subscribe to an existing thread or start your own." : "Prihláste sa do existujúceho vlákna alebo začnite svoje vlastné.",
    "You have no unread mentions." : "Nemáte žiadne neprečítané upozornenia.",
    "You have no unread messages." : "Nemáte žiadne neprečítané správy.",
    "An error occurred while performing the search" : "Pri vyhľadávaní sa vyskytla chyba",
    "Conversation list" : "Zoznam konverzácií",
    "Filter conversations by" : "Filtrovať konverzácie podľa",
    "Unread messages" : "Neprečítané správy",
    "Meeting conversations" : "Konverzácie na stretnutiach",
    "Clear filters" : "Vyčistiť filtre",
    "New personal note" : "Nová osobná poznámka",
    "SIP backend is not installed" : "Backend SIP nie je nainštalovaný",
    "Back to conversations" : "Naspäť do konverzácií",
    "Archived conversations" : "Archivovať konverzácie",
    "Threads" : "Vlákna",
    "Clear filter" : "Vyčistiť filter",
    "Show more threads" : "Zobraziť viac vlákien",
    "App settings" : "Nastavenia Aplikácie",
    "Users" : "Používatelia",
    "Groups" : "Skupiny",
    "Teams" : "Tímy",
    "Federated users" : "Združený užívateľ",
    "New private conversation" : "Nová súkromná konverzácia",
    "Other sources" : "Iné zdroje",
    "Open conversations" : "Otvoriť konverzácie",
    "No search results" : "Žiadne výsledky vyhľadávania",
    "Users, groups and teams" : "Užívatelia, skupiny a tímy",
    "Users and groups" : "Používatelia a skupiny",
    "Users and teams" : "Užívatelia a tímy",
    "Groups and teams" : "Skupiny a tímy",
    "New group conversation" : "Nová skupinová konverzácia",
    "The meeting will start soon" : "Rozhovor začne čoskoro",
    "This meeting is scheduled for {startTime}" : "Tento rozhovor je naplánovaný na {startTime}",
    "You are currently waiting in the lobby" : "Momentálne ste v čakárni",
    "Enable noise suppression" : "Povoliť potlačenie šumu",
    "Reduce background noises for better voice quality" : "Znížiť šum v pozadí pre lepšiu kvalitu hlasu",
    "Enable echo cancellation" : "Povoliť zrušenie ozveny",
    "Minimize echo effect from own surrounding" : "Minimalizovať efekt ozveny z vlastného okolia",
    "Enable auto gain control" : "Povoliť automatické ovládanie zosilnenia",
    "Dynamically adjust microphone volume for consistent level" : "Dynamické upravovanie hlasitosti mikrofónu pre konzistentnú úroveň",
    "Select microphone" : "Vyberte mikrofón",
    "No microphone available" : "Mikrofón nie je k dispozícii",
    "Select speaker" : "Vybrať reproduktor",
    "No speaker available" : "Reproduktor nie je k dispozícii",
    "Select camera" : "Vyberte kameru",
    "No camera available" : "Kamera nie je k dispozícii",
    "Select a device" : "Vyberte zariadenie",
    "Playing …" : "Prehrávam ...",
    "Test speakers" : "Test reproduktorov",
    "Test" : "Vyskúšať",
    "Devices" : "Zariadenia",
    "Backgrounds" : "Pozadia",
    "No audio" : "Žiadny zvuk",
    "No camera" : "Žiadna kamera",
    "Display video as you will see it (mirrored)" : "Zobraziť video ako ho uvidíte vy (zrkadlenie)",
    "Display video as others will see it" : "Zobraziť video ako ho uvidia ostatný",
    "Calls are not supported in your browser" : "Váš prehliadač nepodporuje hovory",
    "Access to microphone is only possible with HTTPS" : "Prístup k mikrofónu je možný iba pomocou protokolu HTTPS",
    "Access to microphone was denied" : "Prístup k mikrofónu bol zamietnutý",
    "Error while accessing microphone" : "Nastala chyba pri prístupe k mikrofónu",
    "Access to camera is only possible with HTTPS" : "Prístup ku kamere je možný iba pomocou protokolu HTTPS",
    "The call is being recorded." : "Hovor sa nahráva.",
    "The call might be recorded." : "Hovor môže byť zaznamenaný.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Záznam by mohol obsahovať váš hlas, video z kamery a zdieľanú obrazovku. Pred pripojením k hovoru je potrebný váš súhlas.",
    "Give consent to the recording of this call" : "Dajte súhlas na nahrávanie tohto hovoru",
    "Show more info" : "Zobraziť viac informácií",
    "Audio is not available" : "Zvuk nie je k dispozícii.",
    "Video is not available" : "Video nie je k dispozícii",
    "Start recording immediately with the call" : "Po začatí hovoru spustiť hneď nahrávanie",
    "Recording backend is not installed" : "Prostredie pre nahrávanie nie je nainštalované",
    "Notify all participants about this call" : "Poslať všetkým účastníkom upozornenie na tento hovor",
    "Apply settings" : "Použiť nastavenia",
    "Select virtual office background" : "Vybrať pozadie virtuálna kancelária",
    "Select virtual home background" : "Vybrať pozadie virtuálny domov",
    "Select virtual abstract background" : "Vybrať virtuálne abstraktné pozadie",
    "Select virtual beach background" : "Vybrať pozadie virtuálna pláž",
    "Select virtual park background" : "Vybrať pozadie virtuálny park",
    "Select virtual theater background" : "Vybrať pozadie virtuálne divadlo",
    "Select virtual library background" : "Vybrať pozadie virtuálna knižnica",
    "Select virtual space station background" : "Vybrať pozadie virtuálna vesmírna stanica",
    "Error while uploading the file" : "Chyba pri nahrávaní súboru",
    "Select a file" : "Vybrať súbor",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Select virtual background from file {fileName}" : "Vybrať virtuálne pozadie zo súboru {fileName}",
    "Blur" : "Rozmazať",
    "Upload" : "Nahrať",
    "Files" : "Súbory",
    "(editing)" : "(upravuje)",
    "(edited)" : "(editované)",
    "The message has expired or has been deleted" : "Správe vypršala platnoť alebo bola zmazaná",
    "Cancel quote" : "Zrušiť citáciu",
    "24 hours" : "24 hodín",
    "7 days" : "7 dní",
    "30 days" : "30 dní",
    "Until unpin" : "Až do odopnutia",
    "Clear reminder – {timeLocale}" : "Zrušiť pripomienku – {timeLocale}",
    "Edited by {actor}" : "Upravené od {actor}",
    "Pinned by you" : "Pripnuté Vami",
    "Pinned by {actor}" : "Pripnuté od{actor}",
    "Until {absoluteDate}" : "Do {absoluteDate}",
    "Message text copied to clipboard" : "Text správy bol skopírovaný do schránky",
    "Message text could not be copied" : "Text správy sa nepodarilo skopírovať",
    "Message forwarded to \"Note to self\"" : "Správa preposlaná do \"Poznámky pre seba\"",
    "Error while forwarding message to \"Note to self\"" : "Chyba pri preposielaní správy do \"Poznámky pre seba\"",
    "A reminder was successfully removed" : "Pripomienka bola úspešne odstránená",
    "Error occurred when removing a reminder" : " Pri odstraňovaní pripomienky sa vyskytla chyba",
    "A reminder was successfully set at {datetime}" : "Pripomienka bola úspešne nastavená na {datetime}",
    "Error occurred when creating a reminder" : "Pri vytváraní pripomienky sa vyskytla chyba",
    "Add a reaction to this message" : "Reagovať na túto správu",
    "Reply" : "Odpovedať",
    "More actions" : "Viac akcií",
    "Set reminder" : "Nastaviť pripomienku",
    "Pin message" : "Pripnúť správu",
    "Unpin message" : "Odopnúť správu",
    "Reply privately" : "Odpovedať súkromne",
    "Edit message" : "Upraviť správu",
    "Copy message" : "Kopírovať správu",
    "Copy message link" : "Kopírovať odkaz správy",
    "Go to file" : "Prejsť na súbor",
    "Download file" : "Stiahnuť súbor",
    "Go to thread" : "Prejsť na vlákno",
    "Edit thread details" : "Upraviť detaily vlákna",
    "Forward message" : "Preposlať správu",
    "Translate" : "Preložiť",
    "Set custom reminder" : "Nastaviť vlastnú pripomienku",
    "Keep pinned for" : "Zachovať pripnuté pre",
    "Set custom period" : "Nastaviť vlastné obdobie",
    "Close reactions menu" : "Zatvoriť ponuku reakcií",
    "React with {emoji}" : "Reagovať s {emoji}",
    "React with another emoji" : "Reagovať s inou emotikonou.",
    "Choose a conversation to forward the selected message." : "Vyberte konverzáciu, ktorou chcete vybranú správu poslať ďalej.",
    "Error while forwarding message" : "Chyba počas preposielania správy",
    "The message has been forwarded to {selectedConversationName}" : "Správa bola preposlaná na adresu {selectedConversationName}",
    "Dismiss" : "Zatvoriť",
    "Go to conversation" : "Prejisť na konverzáciu",
    "Detect language" : "Zistiť jazyk",
    "The message could not be translated" : "Správa sa nedala preložiť",
    "Translation copied to clipboard" : "Preklad skopírovaný do schránky",
    "Translation could not be copied" : "Preklad sa nepodarilo skopírovať",
    "Translate message" : "Preložiť správu",
    "Source language to translate from" : "Zdrojový jazyk pre preklad",
    "Translate from" : "Preložiť z",
    "Target language to translate into" : "Cieľový jazyk prekladu",
    "Translate to" : "Preložiť do",
    "Translating" : "Prekladanie",
    "This translation is AI generated and may contain mistakes." : "Táto preklad je generovaný pomocou AI a môže obsahovať chyby.",
    "Copy translated text" : "Kopírovať preložený text",
    "Error when scheduling the message" : "Chyba pri plánovaní správy",
    "Reschedule" : "Preplánovať",
    "Send now" : "Odoslať teraz",
    "Choose a time" : "Vyberte čas",
    "Send at custom time" : "Odoslať v upravenom čase",
    "Will be sent without notification" : "Bude odoslané bez upozornenia.",
    "Message read by everyone who shares their reading status" : "Správa prečítaná každým, kto zdieľa svoj stav",
    "Message sent" : "Správa bola odoslaná",
    "Sent without notification" : "Odoslať bez upozornenia",
    "Deleting message" : "Mažem správu",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Správa bola úspešne odstránená, ale bot alebo Matterbridge sú nakonfigurované a správa už môže byť distribuovaná do iných služieb",
    "Message deleted successfully" : "Správa úspešne vymazaná.",
    "Message could not be deleted because it is too old" : "Správa nemôže byť vymazaná pretože je príliš stará",
    "Only normal chat messages can be deleted" : "Odstrániť sa dajú iba bežné správy z četu",
    "An error occurred while deleting the message" : "Pri vymazávaní správy sa vyskytla chyba",
    "Pinned" : "Pripnuté",
    "Your browser does not support playing audio files" : "Váš prehliadač nepodporuje prehrávanie zvukových súborov",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} v {board}",
    "Deck Card" : "Karta aplikácie Deck",
    "Remove {fileName}" : "Dostrániť {fileName}",
    "Open this location in OpenStreetMap" : "Otvoriť toto umiestnenie v Openstreetmap",
    "_%n reply_::_%n replies_" : ["%n odpoveď","%n odpovede","%n odpovedí","%n odpovedí"],
    "Sending message" : "Odosielam správu",
    "Failed to send the message. Click to try again" : "Nepodarilo sa odoslať správu. Kliknite pre opakovanie",
    "Not enough free space to upload file" : "Nie je voľné miesto pre nahranie súboru",
    "You cannot send messages to this conversation at the moment" : "Teraz nemôžete poslať správu do tejto konverzácie",
    "Could not update the message" : "Nepodarilo sa aktualizovať správu",
    "Reply to thread \"{threadTitle}\"" : "Odpovedať na vlákno \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Hlasovali ste • %n hla","Hlasovali ste • %n hlasov","Hlasovali ste • %n hlasov","Hlasovali ste • %n hlasy"],
    "You voted" : "Hlasovali ste",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Kliknite pre hlasovanie • %n hlas","Kliknite pre hlasovanie • %n hlasov","Kliknite pre hlasovanie • %n hlasov","Kliknite pre hlasovanie • %n hlasy"],
    "Click to vote" : "Kliknite pre hlasovanie",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Koncept ankety • %n voľba","Koncept ankety • %n voľby","Koncept ankety • %n volieb","Koncept ankety • %n volieb"],
    "_%n vote_::_%n votes_" : ["%n hlas","%n hlasy","%n hlasov","%n hlasov"],
    "Edit poll draft" : "Upraviť koncept ankety",
    "Delete poll draft" : "Zmazať koncept ankety",
    "Open poll" : "Otvoriť anketu",
    "Closed poll" : "Uzavretá anketa",
    "See results" : "Zobraziť výsledky",
    "Reactions" : "Reakcie",
    "No permission to post reactions in this conversation" : "Nemáte oprávnenie na uverejňovanie reakcií v tomto rozhovore",
    "and {participant}" : "a {participant}",
    "_and %n other participant_::_and %n other participants_" : ["a %n ďalší účastník","a %n ďalší účastníci","a %n ďalších účastníkov","a %n ďalších účastníkov"],
    "Show all reactions" : "Zobraziť všetky reakcie",
    "Add more reactions" : "Pridať viac reakcií",
    "Show or collapse system messages" : "Zobraziť alebo skryť systémové správy",
    "No messages" : "Žiadne správy",
    "All messages have expired or have been deleted." : "Všetkým správam vypršala platnosť alebo boli zmazané.",
    "Generate summary with AI" : "Vygenerovať zhrnutie pomocou AI",
    "{author} (pinned by you)" : "{author} (pripnuté Vami)",
    "{author} (pinned by {actor})" : "{author} (pripnuté od{actor})",
    "Unpin" : "Odopnúť",
    "Cancel search" : "Zrušiť vyhľadávanie",
    "Add a phone number" : "Pridať telefónne číslo",
    "Error: A password is required to create the conversation." : "Chyba: Na vytvorenie konverzácie je potrebné zadať heslo.",
    "All set, the conversation \"{conversationName}\" was created." : "Všetko je pripravené, konverzácia \"{conversationName}\" bola vytvorená.",
    "Create a new group conversation" : "Vytvoriť novú skupinovú konverzáciu",
    "Add participants" : "Pridať účastníkov",
    "Maximum length exceeded ({maxlength} characters)" : "Prekročená maximálna dĺžka ({maxlength} znakov)",
    "Conversation type" : "Typ konverzácie",
    "Conversation visibility" : "Viditeľnosť konverzácie",
    "Allow guests to join via link" : "Umožniť hosťom pripojiť sa prostredníctvom odkazu",
    "Enter password" : "Zadajte heslo",
    "This conversation has been locked" : "Rozhovor bol zamknutý",
    "No permission to post messages in this conversation" : "Nemáte povolenie na uverejňovanie správ v tomto rozhovore",
    "Joining conversation …" : "Pripájam sa ku konverzácii ...",
    "Write a message without notification" : "Napíšte správu bez upozornenia",
    "Create a thread silently" : "Vytvorte vlákno potichu",
    "Create a thread" : "Vytvoriť vlákno",
    "Send message silently" : "Odoslať správu potichu",
    "Send message" : "Odoslať správu",
    "Send without notification" : "Poslať bez upozornenia",
    "The participant will not be notified about new messages" : "Účastník nebude upozornený na nové správy",
    "Participants will not be notified about new messages" : "Účastníci nebudú upozornený na nové správy",
    "Message will be sent {datetimeString}" : "Správa bude odoslaná {datetimeString}",
    "Thread title is required" : "Názov vlákna je povinný",
    "Message text is required" : "Text správy je povinný",
    "The message could not be edited" : "Správu sa nepodarilo upraviť",
    "File to share" : "Súbor na zdieľanie",
    "File upload is not available in this conversation" : "Nahrávanie súboru nie je v tejto konverzácii dostupné",
    "Message was successfully scheduled" : "Správa bola úspešne naplánovaná",
    "Add emoji" : "Pridať emotikonu",
    "Adding a mention will only notify users who did not read the message." : "Pridanie pripomienky upozorní len užívateľov, ktorí správu nečítali.",
    "Thread title" : "Názov vlákna",
    "Send later" : "Odoslať neskôr",
    "Show scheduled messages" : "Zobraziť naplánované správy",
    "Cancel editing" : "Zrušiť úpravy",
    "Schedule message" : "Naplánovať správu",
    "{user} is out of office and might not respond." : "{user} je mimo kancelárie a pravdepodobne nebude odpovedať.",
    "Absence period: {startDate} - {endDate}" : "Obdobie absencie: {startDate} - {endDate}",
    "Replacement:" : "Náhrada:",
    "Share from {nextcloud}" : "Zdieľané z {nextcloud}u",
    "Share from Files" : "Zdieľať zo Súborov",
    "Share files to the conversation" : "Zdieľať súbory v konverzácii",
    "Upload from device" : "Nahrať zo zariadenia",
    "Create new poll" : "Vytvoriť novú anketu",
    "Smart picker" : "Inteligentný výber",
    "Record voice message" : "Nahrať hlasovú správu",
    "End recording and send" : "Zastaviť nahrávanie a odoslať",
    "Dismiss recording" : "Zrušiť nahrávanie",
    "Access to the microphone was denied" : "Prístup k mikrofónu bol zamietnutý",
    "Microphone either not available or disabled in settings" : "Mikrofón buď nie je k dispozícii, alebo je v nastaveniach zakázaný",
    "Error while recording audio" : "Chyba pri nahrávaní zvuku",
    "Voice message {time} ({conversation})" : "Hlasová správa {time} ({conversation})",
    "Generating summary of unread messages …" : "Generovanie súhrnu neprečítaných správ …",
    "Summary is AI generated and might contain mistakes" : "Zhrnutie je generované pomocou AI a môže obsahovať chyby.",
    "Error occurred during a summary generation" : "Došlo k chybe počas generovania súhrnu.",
    "New file" : "Nový súbor",
    "Blank" : "Prázdne",
    "Error while creating file" : "Chyba pri vytváraní súboru",
    "Create and share a new file" : "Vytvoriť a zdieľať nový súbor",
    "Name of the new file" : "Názov nového súboru",
    "Create file" : "Vytvoriť súbor",
    "Someone is typing …" : "Niekto píše ...",
    "{user1} is typing …" : "{user1} píše ...",
    "{user1} and {user2} are typing …" : "{user1} a {user2} píšu ...",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} a {user3} píšu ...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} a %n ďalší píše ...","{user1}, {user2}, {user3} a %n ďalších píše ...","{user1}, {user2}, {user3} a %n ďalších píše ...","{user1}, {user2}, {user3} a %n ďalších píše ..."],
    "Add more files" : "Pridať viac súborov",
    "Send" : "Odoslať",
    "In this conversation <strong>{user}</strong> can:" : "V tomto rozhovore <strong>{user}</strong> môže:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Upraviť predvolené oprávnenia pre účastníkov v <strong>{conversationName}</strong>",
    "Start a call" : "Začať hovor",
    "Skip the lobby" : "Preskočiť čakáreň",
    "Can post messages" : "Môže posielať správy",
    "Can post messages and reactions" : "Môže pridať správu a reagovať",
    "Can add reactions" : "Môže pridať reakcie",
    "Enable the microphone" : "Povoliť mikrofón",
    "Enable the camera" : "Povoliť kameru",
    "Share the screen" : "Zdieľať obrazovku",
    "Update permissions" : "Aktualizovať oprávnenia",
    "Updating permissions" : "Aktualizujem oprávnenia",
    "No poll drafts" : "Žiadne návrhy ankiet",
    "There is no poll drafts yet saved for this conversation" : "Pre túto konverzáciu ešte neboli uložené žiadne návrhy ankiet.",
    "Create poll in {name}" : "Vytvoriť anketu v {name}",
    "Create poll" : "Vytvoriť anketu",
    "Error while importing poll" : "Chyba pri importe ankety",
    "Question" : "Otázka",
    "Ask a question" : "Opýtať sa otázku",
    "Import draft from file" : "Importovať koncept zo súboru",
    "Answers" : "Odpovede",
    "Answer {option}" : "Odpoveď {option}",
    "Delete poll option" : "Odstrániť voľbu z ankety",
    "Add answer" : "Pridať odpoveď",
    "Settings" : "Nastavenia",
    "Anonymous poll" : "Anonymná anketa",
    "Multiple answers" : "Viac odpovedí",
    "Save as draft" : "Uložiť ako koncept",
    "Export draft to file" : "Exportovať koncept do súboru",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Konečné výsledky • %n hlas","Konečné výsledky • %n hlasov","Konečné výsledky • %n hlasov","Konečné výsledky • %n hlasy"],
    "Your vote is anonymous" : "Váš hlas je anonymný",
    "You voted for this option" : "Hlasovali ste pre túto možnosť",
    "End poll" : "Ukončiť anketu",
    "Change your vote" : "Zmeniť hlasovanie",
    "Withdraw vote" : "Stiahnuť hlas",
    "Results" : "Výsledky",
    "Voted participants" : "Hlasujúci účastníci",
    "Send a message to \"{roomName}\"" : "Poslať správu do \"{roomName}\"",
    "Hide list of participants" : "Skryť zoznam účastníkov",
    "Show list of participants" : "Zobraziť zoznam účastníkov",
    "Assistance requested in {roomName}" : "Pomoc požadovaná v {roomName}",
    "The message was sent to \"{roomName}\"" : "Správa bola odoslaná do \"{roomName}\"",
    "Dismiss request for assistance" : "Zamietnuť žiadosť o pomoc",
    "Send message to room" : "Poslať správu do miestnosti",
    "Back to main room" : "Späť do hlavnej miestnosti",
    "Back to your room" : "Späť do vlastnej miestnosti",
    "Message all rooms" : "Správa všetkým miestnostiam",
    "Start session" : "Začať reláciu",
    "Start a call before you start a breakout room session" : "Začať hovor predtým, než začnete sedenie v miestnosti",
    "Stop session" : "Zastaviť reláciu",
    "The message was sent to all breakout rooms" : "Správa bola odoslaná do všetkých miestností.",
    "Send a message to all breakout rooms" : "Poslať správu do všetkých miestností",
    "Breakout rooms are not started" : "Vyhradené miestnosti neboli otvorené",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Hovory bez vysokovýkonného backendu môžu spôsobiť problémy s konektivitou a vysoké zaťaženie zariadení. {linkstart} Zistite viac {linkend}",
    "Talk setup incomplete" : "Nastavenie Talk neúplné",
    "Disable lobby" : "Vypnúť čakáreň",
    "Settings for participant \"{user}\"" : "Nastavenia účastníka \"{user}\"",
    "Participant \"{user}\"" : "Účastník \"{user}\"",
    "moderator" : "moderátor",
    "bot" : "bot",
    "guest" : "hosť",
    "Ringing …" : "Zvoní ...",
    "Call rejected" : "Hovor odmietnutý",
    "{time} talking …" : "hovorí {time}  ...",
    "{time} talking time" : "{time} čas hovoru",
    "Raised their hand" : "Zdvihli ruky",
    "Joined with video" : "Pripojené s videom",
    "Joined via phone" : "Pripojené cez telefón",
    "Joined with audio" : "Pripojené so zvukom",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Popis musí byť menší alebo rovný {maxLength} znakov. Váš aktuálny text má {charactersCount} znakov.",
    "Remove group and members" : "Odobrať skupinu a členov",
    "Remove team and members" : "Odstrániť tím a členov",
    "Remove participant" : "Odstrániť účastníka",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Naozaj chcete odstrániť skupinu \"{displayName}\" a jej členov z tejto konverzácie?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Naozaj chcete odstrániť tím \"{displayName}\" a jeho členov z tejto konverzácie?",
    "Do you really want to remove {displayName} from this conversation?" : "Naozaj chcete odstrániť {displayName} z tejto konverzácie?",
    "Notification was sent to {displayName}" : "Pozvánka odoslaná pre {displayName}",
    "Could not send notification to {displayName}" : "Nemôžem odoslať pozvánku pre {displayName}",
    "Permissions granted to {displayName}" : "Oprávnenia udelené pre {displayName}",
    "Could not modify permissions for {displayName}" : "Nie je možné upraviť oprávnenia pre {displayName}",
    "Permissions removed for {displayName}" : "Oprávnenia pre {displayName} boli odstránené",
    "Permissions set to default for {displayName}" : "Oprávnenia pre {displayName} boli nastavené na predvolené",
    "Phone number could not be hung up" : "Telefónne číslo sa nedalo zavolať",
    "Phone number could not be put on hold" : "Hovor nebolo možné podržať",
    "Phone number could not be muted" : "Hovor nebolo možné stíšiť",
    "Phone number could not be unmuted" : "Nebolo možné zrušiť stíšenie pre hovor",
    "DTMF message could not be sent" : "Správu DTMF sa nepodarilo odoslať",
    "Phone number copied to clipboard" : "Telefónne číslo bolo skopírované do schránky",
    "Phone number could not be copied" : "Telefónne číslo sa nemôže byť skopírované",
    "in the lobby" : "v hale",
    "Dial out phone" : "Vytočiť telefónne číslo",
    "Hang up phone" : "Zdvihnúť telefón",
    "Move back to lobby" : "Vrátiť sa do lobby",
    "Move to conversation" : "Presunúť do konverzácie",
    "Dial-in PIN" : "PIN pre príchodzie hovory",
    "Demote from moderator" : "Odobrať moderovanie",
    "Promote to moderator" : "Povýšiť na moderátora",
    "Resend invitation" : "Znovu odoslať pozvánku",
    "Send call notification" : "Odoslať upozornenie na hovor",
    "Dial out phone number" : "Vytočiť telefónne číslo",
    "Resume call for phone number" : "Obnoviť hovor pre telefónne číslo",
    "Put phone number on hold" : "Podržať hovor",
    "Unmute phone number" : "Zrušiť stlmenie telefónneho čísla",
    "Mute phone number" : "Stlmiť telefónne číslo",
    "Copy phone number" : "Kopírovať telefónne číslo",
    "Reset custom permissions" : "Obnoviť vlastné oprávnenia",
    "Grant all permissions" : "Udeliť všetky oprávnenia",
    "Remove all permissions" : "Odstrániť všetky oprávnenia",
    "Also ban from this conversation" : "Tiež zakázať prístup k tejto konverzácii",
    "Internal note (reason to ban)" : "Interná poznámka (dôvod zákazu)",
    "Remove" : "Odobrať",
    "Permissions modified for {displayName}" : "Oprávnenia pre {displayName} boli upravené",
    "Add users, groups or teams" : "Pridať užívateľov, skupiny alebo tímy",
    "Add users or groups" : "Pridať používateľov alebo skupiny",
    "Add users or teams" : "Pridajte užívateľov alebo tímy",
    "Add users" : "Pridať používateľov",
    "Add groups or teams" : "Pridať skupiny alebo tímy",
    "Add groups" : "Pridať skupiny",
    "Add teams" : "Pridať tímy",
    "Add other sources" : "Pridať iné zdroje",
    "Add emails" : "Pridať e-maily",
    "Integrations" : "Integrácie",
    "Add federated users" : "Pridajte združených používateľov",
    "Searching …" : "Hľadá sa …",
    "Search for more users" : "Vyhľadajte ďalších používateľov",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Môžete vyhľadávať alebo pridávať účastníkov podľa mena, e-mailu alebo Federovaného cloudového ID.",
    "Search or add participants" : "Vyhľadať alebo pridať účastníkov",
    "Invitation was sent to {actorId}" : "Pozvánka odoslaná pre {actorId}",
    "An error occurred while adding the participants" : "Pri pridávaní účastníkov sa vyskytla chyba",
    "A new group conversation with selected participant will be created" : "Bude vytvorený nový skupinový rozhovor so zvoleným účastníkom",
    "Participants" : "Účastníci",
    "Pinned by a deleted user" : "Pripnuté používateľom, ktorý bol odstránený",
    "Participants ({count})" : "({count}) účastníkov",
    "Open chat" : "Otvoriť rozhovor",
    "You have new unread messages in the chat." : "Máte novú neprečítanú správu v rozhovore.",
    "You have been mentioned in the chat." : "Boli ste spomenutý v rozhovore.",
    "Search messages" : "Vyhľadať správy",
    "Chat" : "Správy",
    "Details" : "Podrobnosti",
    "Shared items" : "Zdieľané položky",
    "Search in {name}" : "Vyhľadať v {name}",
    "Threads in {name}" : "Vlákien v {name}",
    "{actor} in {conversation}" : "{actor} v {conversation}",
    "Search messages …" : "Vyhľadať správy ...",
    "Search options" : "Možnosti vyhľadávania",
    "From User" : "Od Užívateľa",
    "Since" : "Do",
    "Until" : "Do",
    "No results found" : "Neboli nájdené žiadne výsledky",
    "Load more results" : "Načítať viac výsledkov",
    "Recent threads" : "Nedávne vlákna",
    "Projects" : "Projekty",
    "No shared items" : "Žiadne zdieľané položky",
    "Thread notifications" : "Upozornenia na vlákna",
    "Thread actions" : "Akcie vlákna",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Odkaz na konverzáciu",
    "No open conversations found" : "Neboli nájdené žiadne prebiehajúce konverzácie",
    "Either there are no open conversations or you joined all of them." : "Buď aktuálne neprebiehajú žiadne konverzácie alebo sa už všetkých účastníte.",
    "Check spelling or use complete words." : "Skontrovať pravopis alebo použiť celé slová.",
    "Search conversations or users" : "Vyhľadajte konverzácie alebo používateľov",
    "Select conversation" : "Vybrať konveráciu",
    "Number length is not valid" : "Dĺžka čísla nie je platná",
    "Region code is not valid" : "Kód predvoľby nie je platný",
    "Number length is too short" : "Dĺžka čísla je príliš krátka",
    "Number length is too long" : "Číslo je príliš dlhé",
    "Number is not valid" : "Číslo nie je platné",
    "Phone numbers" : "Telefónne čísla",
    "Display name: {name}" : "Zobrazované meno: {name}",
    "Edit display name" : "Upraviť zobrazované meno",
    "Display name (required)" : "Zobrazované meno (povinné)",
    "Save name" : "Uložiť meno",
    "I picked message bubbles" : "Vybral/a som si správy v bublinách",
    "I picked the list style" : "Vybral som štýl zoznamu",
    "Error while setting personal setting" : "Chyba pri nastavovaní osobného nastavenia",
    "Error while saving sounds setting" : "Chyba pri ukladaní nastavenia zvuku",
    "Compact conversations list" : "Zoznam kompaktných rozhovorov",
    "Chat appearance" : "Vzhľad chatu",
    "Messages list" : "Zoznam správ",
    "Message bubbles" : "Bubliny správ",
    "Play sounds when participants join or leave a call" : "Prehrávať zvuky, keď sa účastníci pripoja alebo odchádzajú z hovoru",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Momentálne nie je k dispozícii na iPhone a iPade z dôvodu technických obmedzení výrobcu.",
    "Notification settings" : "Nastavenie notifikácií",
    "Sounds for chat and call notifications" : "Zvuky pre upozornenia na chat a hovory",
    "Invalid language ({languageId})" : "Neplatný jazyk ({languageId})",
    "Default language" : "Predvolený jazyk",
    "Default language ({languageName})" : "Predvolený jazyk ({languageName})",
    "Error when trying to load the available live translation languages" : "Chyba pri pokuse o načítanie dostupných jazykov živého prekladu",
    "Error when trying to set live translation language" : "Chyba pri pokuse o nastavenie jazyka živého prekladu",
    "Set language used to show the transcriptions" : "Nastaviť jazyk, ktorý sa použije na zobrazenie prepisov",
    "Select location for attachments" : "Vyberte umiestnenie príloh",
    "Error while setting attachment folder" : "Pri nastavovaní priečinka pre prílohy sa vyskytla chyba",
    "Error while setting read status privacy" : "Chyba pri nastavovaní oznámenia o prečítaní",
    "Error while setting typing status privacy" : "Chyba pri nastavovaní súkromného stavu písania",
    "Error while setting default media state" : "Chyba pri nastavovaní predvoleného stavu médií",
    "Turn camera and microphone off by default" : "Vypnúť kameru a mikrofón predvolene",
    "Blur camera background by default" : "Rozmazať pozadie kamery predvolene",
    "Skip device preview before joining a call" : "Preskočiť náhľad zariadenia pred pripojením k hovoru",
    "Appearance & Sounds" : "Vzhľad a Zvuky",
    "Privacy" : "Súkromie",
    "Send read receipts" : "Odoslať potvrdenia o prečítaní",
    "When off, all read statuses will be hidden" : "Keď je vypnuté, všetky stavy čítania budú skryté.",
    "Share typing status" : "Zdieľať stav písania",
    "When off, all typing indicators will be hidden" : "Keď je vypnuté, všetky indikátory písania budú skryté.",
    "Attachments folder" : "Priečinok s prílohami",
    "Toggle full screen" : "Prepnúť režim celej obrazovky",
    "Return to Home screen" : "Návrat na domovskú obrazovku",
    "Search" : "Hľadať",
    "Shortcuts while in a chat" : "Skratky počas chatu",
    "Focus the chat input" : "Zamerať na písanie v čete",
    "Unfocus the chat input to use shortcuts" : "Aby ste mohli používať klávesové skratky, je treba zrušiť zameranie na písanie v čete",
    "Edit your last message" : "Upraviť vašu poslednú správu",
    "Shortcuts while in a call" : "Klávesové skratky počas hovoru",
    "Camera on and off" : "Zapnúť a vypnúť video",
    "Microphone on and off" : "Zapnúť a vypnúť mikrofón",
    "Raise or lower hand" : "Zdvihnúť alebo dať dole ruku",
    "Push to talk or push to mute" : "Stlačte a hovorte alebo stlačte pre stlmenie",
    "Zoom-in / zoom-out a screen share" : "Priblíženie / oddialenie zdieľania obrazovky",
    "Mouse wheel" : "Kolečko myši",
    "Start call silently" : "Začat hovor potichu",
    "Start call" : "Začať hovor",
    "End call" : "Ukončiť hovor",
    "The server was updated, you cannot start or join a call." : "Server bol aktualizovaný, nemôžete začať ani sa pripojiť k hovoru.",
    "This call has just ended" : "Hovor práve skončil",
    "You will be able to join the call only after a moderator starts it." : "K hovoru sa budete môcť pripojiť až potom, keď ho moderátor začne.",
    "End call for everyone" : "Ukončiť hovor pre všetkých",
    "Starting the recording" : "Začínam nahrávanie",
    "Recording" : "Záznam",
    "The call has been running for one hour." : "Hovor už trvá viac ako jednu hodinu.",
    "Cancel recording start" : "Zrušiť začiatok nahrávania",
    "Stop recording" : "Zastaviť nahrávanie",
    "Send a reaction" : "Poslať reakciu",
    "React with {reaction}" : "Reagovať s {reaction}",
    "All tasks done!" : "Všetky úlohy boli splnené!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} z %n úlohy","{done} z %n úloh","{done} z %n úloh","{done} z %n úloh"],
    "Add participants to this call" : "Pridať účastníkov do tohto hovoru",
    "_%n participant in call_::_%n participants in call_" : ["%n účastník v hovore","%n účastníci v hovore","%n účastníkov v hovore","%n účastníkov v hovore"],
    "Scheduled messages" : "Plánované správy",
    "You are not allowed to enable screensharing" : "Nemáte oprávnenie k zdieľaniu obrazovky",
    "No screensharing" : "Žiadne zdieľanie obrazovky",
    "Screensharing options" : "Nastavenia zdieľania obrazovky",
    "Enable screensharing" : "Povoliť zdieľanie obrazovky",
    "Bad sent video and screen quality." : "Zlá kvalita odoslaného videa a rozlíšenia.",
    "Bad sent screen quality." : "Zlá kvalita odoslaného rozlíšenia.",
    "Bad sent video quality." : "Zlá kvalita odoslaného videa.",
    "Bad sent audio, video and screen quality." : "Zlá kvalita odoslaného zvuku, videa a rozlíšenia.",
    "Bad sent audio and screen quality." : "Zlá kvalita odoslaného zvuku a rozlíšenia.",
    "Bad sent audio and video quality." : "Zlá kvalita odoslaného zvuku a videa.",
    "Bad sent audio quality." : "Zlá kvalita odoslaného zvuku.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci nemusia vidieť vašu obrazovku. Ak chcete situáciu zlepšiť, skúste zakázať rozmazávanie pozadia alebo zakázať video počas zdieľania obrazovky.",
    "Disable background blur" : "Vypnúť rozmazanie pozadia",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vás nemusia vidieť. Ak chcete situáciu zlepšiť, skúste počas zdieľania obrazovky zakázať video.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci nemusia vidieť vašu obrazovku.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vás nemusia vidieť.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vás nemusia vidieť. Ak chcete situáciu zlepšiť, skúste zakázať rozmazávanie pozadia alebo zakázať video počas zdieľania obrazovky.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vám nemusia rozumieť a/alebo vás vidieť. Ak chcete situáciu zlepšiť, skúste počas zdieľania obrazovky zakázať video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vám nemusia rozumieť a/alebo vidieť vašu obrazovku. Ak chcete situáciu zlepšiť, skúste zakázať zdieľanie obrazovky.",
    "Disable screenshare" : "Zakázať zdieľanie obrazovky",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vás nemusia vidieť. Ak chcete situáciu zlepšiť, skúste zakázať rozmazávanie pozadia alebo zakázať video.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vám nemusia rozumieť a/alebo vás vidieť. Ak chcete situáciu zlepšiť, skúste počas zakázať video.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vaše internetové pripojenie alebo počítač sú zaneprázdnené a ostatní účastníci vás možno nebudú rozumieť.",
    "Screen sharing is not supported by your browser." : "Váš prehliadač nepodporuje zdieľanie obrazovky.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Zdieľanie obrazovky vyžaduje načítanie stránka cez HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Zdieľanie obrazovky vyžaduje, aby bola stánka načítaná cez protokol HTTPS.",
    "An error occurred while starting screensharing." : "Pri pokuse o zdieľanie obrazovky nastala chyba.",
    "Select virtual background" : "Vybrať virtuálne pozadie",
    "Show your screen" : "Ukázať Vašu obrazovku",
    "Stop screensharing" : "Zastaviť zdieľanie obrazovky",
    "Mute others" : "Stlmiť ostatných",
    "Start recording" : "Spustiť nahrávanie",
    "Set up breakout rooms" : "Nastaviť vyhradené miestnosti",
    "Download attendance list" : "Stiahnuť zoznam účastníkov",
    "Open Calendar" : "Otvoriť Kalendár",
    "Remove participant {name}" : "Odobrať účastníka {name}",
    "Would you like to delete this conversation?" : "Chceli by ste túto konverzáciu vymazať?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Táto konverzácia bude automaticky odstránená pre všetkých po %n dni nečinnosti.","Táto konverzácia bude automaticky odstránená pre všetkých po %n dňoch nečinnosti.","Táto konverzácia bude automaticky odstránená pre všetkých po %n dňoch nečinnosti.","Táto konverzácia bude automaticky odstránená pre všetkých po %n dňoch nečinnosti."],
    "Are you sure you want to delete this conversation?" : "Ste si istí, že chcete túto konverzáciu vymazať?",
    "Delete now" : "Odstrániť teraz",
    "Keep" : "Ponechať",
    "Open dialpad" : "Otvoriť číselník",
    "Select a region" : "Vyberte oblasť",
    "Local time: {time}" : "Miestny čas: {time}",
    "Scheduled {datetime}" : "Naplánované {datetime}",
    "Scheduled for {datetime}" : "Naplánované na {datetime}",
    "Search …" : "Hľadať …",
    "Message without mention" : "Správa bez zmienky",
    "Mention myself" : "Spomenúť seba",
    "Mention everyone" : "Spomenúť všetkých",
    "Select a conversation" : "Vybrať rozhovor",
    "Select a mode" : "Vybrať režim",
    "You do not have permissions to access this conversation." : "Nemáte povolenie na prístup k tejto konverzácii.",
    "Join a different conversation or start a new one." : "Pridajte sa k inej konverzácii alebo začnite novú.",
    "The conversation does not exist" : "Konverzácia neexistuje",
    "Join a conversation or start a new one!" : "Pripojte sa k rozhovoru alebo začnite nový!",
    "Duplicate session" : "Zduplikovať sedenie",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Táto konverzácia bola otvorená v inom paneli. Súčasná verzia servera nepodporuje otváranie konverzácie vo viacerých paneloch.",
    "Creating and joining a conversation with \"{userid}\"" : "Vytváranie konverzácie s užívateľom „{userid}“ a pripojenie sa k nej",
    "Join a conversation or start a new one" : "Pripojte sa k rozhovoru alebo začnite nový",
    "Error while joining the conversation" : "Chyba pri pripájaní sa ku konverzácii",
    "Another user" : "Iný používateľ",
    "Hey! Are you using the list style or message bubbles?" : "Ahoj! Používaš štýl zoznamu alebo bubliny správ?",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Používateľ Nextcloud",
    "User password" : "Heslo používateľa",
    "Talk conversation" : "Konverzácia v Talk /Rozhovore/",
    "Skip TLS verification" : "Preskočiť overovanie TLS",
    "Matrix server URL" : "URL Matrix servera",
    "User" : "Používateľ",
    "Matrix channel" : "Matrix kanál",
    "Mattermost server URL" : "URL Mattermost servera",
    "Mattermost user" : "Používateľ Mattermost",
    "Team name" : "Názov tímu",
    "Channel name" : "Názov kanálu",
    "Rocket.Chat server URL" : "URL Rocket.Chat servera",
    "User name or email address" : "Užívateľské meno alebo e-mailová adresa",
    "Rocket.Chat channel" : "Rocket.Chat kanál",
    "Zulip server URL" : "URL Zulip servera",
    "Bot user name" : "Používateľské meno bota",
    "Bot API key" : "Kľúč k API pre bota",
    "Zulip channel" : "Zulip kanál",
    "API token" : "API token",
    "Slack channel" : "Slack kanál",
    "Server ID or name" : "Identifikátor alebo názov servera",
    "Channel ID (prefixed with \"ID:\") or name" : "ID kanála (s predponou \"ID:\") alebo názov",
    "Channel" : "Kanál",
    "Login" : "Prihlásiť sa",
    "Chat ID" : "Identifikátor četu",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL IRC servera (napr. chat.freenode.net:6667)",
    "Nickname" : "Prezývka",
    "Connection password" : "Heslo pripojenia",
    "IRC channel" : "IRC kanál",
    "Channel password" : "Heslo pre kanál",
    "NickServ nickname" : "Prezývka na NickServ",
    "NickServ password" : "Heslo pre NickServ",
    "Use TLS" : "Použiť TLS",
    "Use SASL" : "Použiť SASL",
    "Tenant ID" : "Identifikátor Tenant",
    "Client ID" : "Client ID",
    "Team ID" : "Identifikátor tímu",
    "Thread ID" : "Identifikátor vlákna",
    "XMPP/Jabber server URL" : "URL XMPP/Jabber servera",
    "MUC server URL" : "URL MUC servera",
    "Jabber ID" : "Identifikátor Jabber",
    "Pinned messages" : "Pripnuté správy",
    "Media" : "Média",
    "Polls" : "Ankety",
    "Deck cards" : "Karty aplikácie Deck",
    "Voice messages" : "Hlasové správy",
    "Locations" : "Umiestnenie",
    "Call recordings" : "Zoznam nahraných hovorov",
    "Audio" : "Zvuk",
    "Show all pinned messages" : "Zobraziť všetky pripnuté správy",
    "Show all media" : "Zobraziť všetky médiá",
    "Show all files" : "Zobraziť všetky súbory",
    "Show all polls" : "Zobraziť všetky ankety",
    "Show all deck cards" : "Zobraziť všetky karty deck",
    "Show all voice messages" : "Zobraziť všetky hlasové správy",
    "Show all locations" : "Zobraziť všetky umiestnenia",
    "Show all call recordings" : "Zobraziť všetky nahrávky hovorov",
    "Show all audio" : "Zobraziť všetku hudbu",
    "Show all other" : "Zobraziť všetko ostatné",
    "Follow conversation settings" : "Sledovať nastavenia konverzácie",
    "Group" : "Skupina",
    "Team" : "Tím",
    "You reconnected to the call" : "Opäť ste sa pripojili k hovoru",
    "{actor} reconnected to the call" : "{actor} sa opäť pripojil k hovoru",
    "You added {user0} and {user1}" : "Pridali ste {user0} a {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Pridali ste účastníkov {user0}, {user1} a ďalšieho %n","Pridali ste účastníkov {user0}, {user1} a ďalších %n","Pridali ste účastníkov {user0}, {user1} a ďalších %n","Pridali ste účastníkov {user0}, {user1} a ďalších %n"],
    "An administrator added you and {user0}" : "Správca pridal vás a {user0}",
    "{actor} added you and {user0}" : "{actor} pridal/a vás a {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Administrátor pridal vás, užívateľa {user0} a %n ďalšieho účastníka","Administrátor pridal vás, užívateľa {user0} a %n ďalších účastníkov","Administrátor pridal vás, užívateľa {user0} a %n ďalších účastníkov","Administrátor pridal vás, užívateľa {user0} a %n ďalších účastníkov"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} pridal vás, užívateľa {user0} a %n ďalšieho účastníka","{actor} pridal vás, užívateľa {user0} a %n ďalších účastníkov","{actor} pridal vás, užívateľa {user0} a %n ďalších účastníkov","{actor} pridal vás, užívateľa {user0} a %n ďalších účastníkov"],
    "An administrator added {user0} and {user1}" : "Administrátor pridal {user0} a {user1}",
    "{actor} added {user0} and {user1}" : "{actor} pridal {user0} a {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Administrátor pridal {user0}, {user1} a %n ďalšieho účastníka","Administrátor pridal {user0}, {user1} a %n ďalších účastníkov","Administrátor pridal {user0}, {user1} a %n ďalších účastníkov","Administrátor pridal {user0}, {user1} a %n ďalších účastníkov"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} pridal {user0}, {user1} a %n ďalšieho účastníka","{actor} pridal {user0}, {user1} a %n ďalších účastníkov","{actor} pridal {user0}, {user1} a %n ďalších účastníkov","{actor} pridal {user0}, {user1} a %n ďalších účastníkov"],
    "You removed {user0} and {user1}" : "Odstránili ste {user0} a {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Odstránili ste {user0}, {user1} a %n účastníka","Odstránili ste {user0}, {user1} a %n účastníkov","Odstránili ste {user0}, {user1} a %n účastníkov","Odstránili ste {user0}, {user1} a %n účastníkov"],
    "An administrator removed you and {user0}" : "Administrátor odstránil vás a {user0}",
    "{actor} removed you and {user0}" : "{actor} odstránil vás a {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Administrátor odstránil vás, užívateľa {user0} a %n ďalšieho účastníka","Administrátor odstránil vás, užívateľa {user0} a %n ďalších účastníkov","Administrátor odstránil vás, užívateľa {user0} a %n ďalších účastníkov","Administrátor odstránil vás, užívateľa {user0} a %n ďalších účastníkov"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} odstránil vás, {user0} a %n ďalšieho účastníka","{actor} odstránil vás, {user0} a %n ďalších účastníkov","{actor} odstránil vás, {user0} a %n ďalších účastníkov","{actor} odstránil vás, {user0} a %n ďalších účastníkov"],
    "An administrator removed {user0} and {user1}" : "Administrátor odstránil {user0} a {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} odstránil {user0} a {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Administrátor odstránil {user0}, {user1} a %n ďalšieho účastníka","Administrátor odstránil {user0}, {user1} a %n ďalších účastníkov","Administrátor odstránil {user0}, {user1} a %n ďalších účastníkov","Administrátor odstránil {user0}, {user1} a %n ďalších účastníkov"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} odstránil {user0}, {user1} a %n ďalšieho účastníka","{actor} odstránil {user0}, {user1} a %n ďalších účastníkov","{actor} odstránil {user0}, {user1} a %n ďalších účastníkov","{actor} odstránil {user0}, {user1} a %n ďalších účastníkov"],
    "You and {user0} joined the call" : "Vy a {user0} ste sa pridali k hovoru",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Vy, {user0} a %n účastník sa pridali k hovoru","Vy, {user0} a %n účastníci sa pridali k hovoru","Vy, {user0} a %n účastníkov sa pridali k hovoru","Vy, {user0} a %n účastníkov sa pridali k hovoru"],
    "{user0} and {user1} joined the call" : "{user0} a {user1} sa pridali k hovoru",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} a %n účastník sa pridali k hovoru","{user0}, {user1} a %n účastníci sa pridali k hovoru","{user0}, {user1} a %n účastníkov sa pridali k hovoru","{user0}, {user1} a %n účastníkov sa pridali k hovoru"],
    "You and {user0} left the call" : "Vy a {user0} opustili hovor",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Vy, {user0} a %n účastník opustili hovor","Vy, {user0} a %n účastníci opustili hovor","Vy, {user0} a %n účastníkov opustilo hovor","Vy, {user0} a %n účastníkov opustilo hovor"],
    "{user0} and {user1} left the call" : "{user0} a {user1} opustili hovor",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} a %n účastník opustili hovor","{user0}, {user1} a %n účastníci opustili hovor","{user0}, {user1} a %n účastníkov opustilo hovor","{user0}, {user1} a %n účastníkov opustilo hovor"],
    "You promoted {user0} and {user1} to moderators" : "Povýšili ste {user0} a {user1} na moderátorov",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Povýšili ste {user0}, {user1} a %n účastníka na moderátorov","Povýšili ste {user0}, {user1} a %n účastníkov na moderátorov","Povýšili ste {user0}, {user1} a %n účastníkov na moderátorov","Povýšili ste {user0}, {user1}  a %n účastníkov na moderátorov"],
    "An administrator promoted you and {user0} to moderators" : "Administrátor povýšil vás a {user0} na moderátora",
    "{actor} promoted you and {user0} to moderators" : "{actor} povýšil vás a {user0} na moderátorov",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Administrátor povýšil vás, {user0} a %n účastníka na moderátorov","Administrátor povýšil vás, {user0} a %n účastníkov na moderátorov","Administrátor povýšil vás, {user0} a %n účastníkov na moderátorov","Administrátor povýšil vás, {user0} a %n účastníkov na moderátorov"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} povýšil vás, {user0} a %n účastníka na moderátorov","{actor} povýšil vás, {user0} a %n účastníkov na moderátorov","{actor} povýšil vás, {user0} a %n účastníkov na moderátorov","{actor} povýšil vás, {user0} a %n účastníkov na moderátorov"],
    "An administrator promoted {user0} and {user1} to moderators" : "Administrátor povýšil {user0} a {user1} na moderátorov",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} povýšil {user0} a {user1} na moderátorov",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Administrátor povýšil {user0}, {user1} a ďalších %n účastníka na moderátorov","Administrátor povýšil {user0}, {user1} a ďalších %n účastníkov na moderátorov","Administrátor povýšil {user0}, {user1} a ďalších %n účastníkov na moderátorov","Administrátor povýšil {user0}, {user1} a ďalších %n účastníkov na moderátorov"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} povýšil {user0}, {user1} a %n účastníka na moderátorov","{actor} povýšil {user0}, {user1} a %n účastníkov na moderátorov","{actor} povýšil {user0}, {user1} a %n účastníkov na moderátorov","{actor} povýšil {user0}, {user1}  a %n účastníkov na moderátorov"],
    "You demoted {user0} and {user1} from moderators" : "Degradovali ste {user0} a {user1} z moderátorov",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Degradovali ste {user0}, {user1} a %n účastníka z moderátorov","Degradovali ste {user0}, {user1} a %n účastníkov z moderátorov","Degradovali ste {user0}, {user1} a %n účastníkov z moderátorov","Degradovali ste {user0}, {user1}  a %n účastníkov z moderátorov"],
    "An administrator demoted you and {user0} from moderators" : "Administrátor degradoval vás a {user0} z moderátorov",
    "{actor} demoted you and {user0} from moderators" : "{actor} degradoval vás a {user0} z moderátorov",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Administrátor degradoval vás, {user0} a %n účastníka z moderátorov","Administrátor degradoval vás, {user0} a %n účastníkov z moderátorov","Administrátor degradoval vás, {user0} a %n účastníkov z moderátorov","Administrátor degradoval vás, {user0} a %n účastníkov z moderátorov"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} degradoval vás, {user0} a %n účastníka z moderátorov","{actor} degradoval vás, {user0} a %n účastníkov z moderátorov","{actor} degradoval vás, {user0} a %n účastníkov z moderátorov","{actor} degradoval vás, {user0} a %n účastníkov z moderátorov"],
    "An administrator demoted {user0} and {user1} from moderators" : "Administrátor degradoval {user0} a {user1} na moderátorov",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} degradoval {user0} a {user1} z moderátorov",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Administrátor degradoval {user0}, {user1} a ďalších %n účastníka z moderátorov","Administrátor degradoval {user0}, {user1} a ďalších %n účastníkov z moderátorov","Administrátor degradoval {user0}, {user1} a ďalších %n účastníkov z moderátorov","Administrátor degradoval {user0}, {user1} a ďalších %n účastníkov z moderátorov"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} degradoval {user0}, {user1} a %n účastníka z moderátorov","{actor} degradoval {user0}, {user1} a %n účastníkov z moderátorov","{actor} degradoval {user0}, {user1} a %n účastníkov z moderátorov","{actor} degradoval {user0}, {user1} a %n účastníkov z moderátorov"],
    "You:" : "Vy",
    "You: {lastMessage}" : "Vy: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Server bol aktualizovaný.",
    "(edited by you)" : "(editované vami)",
    "(edited by a deleted user)" : "(editoval zmazaný užívateľ)",
    "(edited by {moderator})" : "(editoval {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "K rozhovoru sa pokúšate pripojiť počas aktívnej relácie v inom okne alebo zariadení. Nextcloud Talk /Rozhovor/ v súčasnosti túto možnosť nepodporuje. Čo chcete urobiť?",
    "Leave this page" : "Opustiť túto stránku",
    "Join here" : "Pripojiť sa tu",
    "Deck card has been posted to {conversation}" : "Karta Deck bola odoslaná do {conversation}",
    "An error occurred while posting deck card to conversation" : "Pri odosielaní karty do konverzácie aplikácie Deck nastala chyba",
    "Post to a conversation" : "Uverejniť príspevok v konverzácii",
    "Post to conversation" : "Uverejniť príspevok v konverzácii",
    "The recording failed. Please contact your administrator." : "Nahrávanie zlyhalo. Prosím, kontaktujte správcu.",
    "Location has been posted to {conversation}" : "Miesto bolo odoslané do {conversation}",
    "An error occurred while posting location to conversation" : "Pri odosielaní umiestnenia do konverzácie nastala chyba",
    "Share to a conversation" : "Zdieľať v rozhovore",
    "Share to conversation" : "Zdieľat v rozhovore",
    "In conversation" : "V konverzácii",
    "Search in conversation: {conversation}" : "Hľadať v konverzácii: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Vaše požiadavky sú momentálne obmedzené z dôvodu ochrany pred útokom hrubou silou",
    "Error while clearing conversation history" : "Chyba pri čistení histórie konverzácie",
    "Error occurred while allowing guests" : "Pri povoľovaní hostí nastala chyba",
    "Error occurred while disallowing guests" : "Pri zakazovaní hostí nastala chyba",
    "Error occurred when restricting the conversation to moderator" : "Pri obmedzovaní konverzácie na moderátora sa vyskytla chyba",
    "Error occurred when opening the conversation to everyone" : "Pri otváraní konverzácie pre všetkých sa vyskytla chyba",
    "Conversation password has been saved" : "Heslo konverzácie bolo uložené",
    "Conversation password has been removed" : "Heslo konverzácie bolo odstránené",
    "Error occurred while saving conversation password" : "Pri ukladaní hesla konverzácie sa vyskytla chyba",
    "Call recording is starting." : "Spúšťa sa nahrávanie hovoru.",
    "Call recording stopped while starting." : "Nahrávanie hovoru zastavené počas spúšťania.",
    "Call recording stopped. You will be notified once the recording is available." : "Nahrávanie hovoru bolo zastavené. Keď bude záznam dostupný, budete informovaní.",
    "Conversation picture set" : "Obrázok konverzácie bol nastavený",
    "Conversation picture deleted" : "Obrázok konverzácie bol zmazaný",
    "Could not delete the conversation picture" : "Nepodarilo sa zmazať obrázok konverzácie",
    "Could not remove the automatic expiration" : "Nebolo možné odstrániť automatické vypršanie platnosti",
    "Could not post message: {errorMessage}" : "Správu sa nepodarilo zverejniť: {errorMessage}",
    "Participant is banned successfully" : "Účastník bol úspešne zablokovaný",
    "Error while banning the participant" : "Chyba pri zablokovaní účastníka",
    "An error occurred while fetching the participants" : "Pri načítavaní účastníkov sa vyskytla chyba",
    "Could not send invitation to {actorId}" : "Nemôžem odoslať pozvánku pre {actorId}",
    "Invitations sent" : "Pozvánky odoslané",
    "Error occurred when sending invitations" : "Pri posielaní pozvánok nastala chyba",
    "Failed to join the conversation." : "Nepodarilo sa pripojiť k hovoru.",
    "An error occurred while creating breakout rooms" : "Pri vytváraní oddelených miestností sa vyskytla chyba",
    "An error occurred while re-ordering the attendees" : "Pri opätovnom zvolávaní účastníkov sa vyskytla chyba",
    "An error occurred while deleting breakout rooms" : "Pri odstraňovaní oddelených miestností sa vyskytla chyba",
    "An error occurred while starting breakout rooms" : "Pri spúšťaní oddelených miestností sa vyskytla chyba",
    "An error occurred while stopping breakout rooms" : "Pri zastavovaní oddelených miestností sa vyskytla chyba",
    "An error occurred while sending a message to the breakout rooms" : "Pri odosielaní správy do oddelených miestností sa vyskytla chyba",
    "An error occurred while requesting assistance" : "Pri žiadosti o pomoc sa vyskytla chyba",
    "An error occurred while resetting the request for assistance" : "Pri resetovaní žiadosti o pomoc sa vyskytla chyba",
    "An error occurred while joining breakout room" : "Pri pripájaní k oddelenej miestnosti sa vyskytla chyba",
    "Failed to rename the thread" : "Nezabezpečilo sa premenovanie vlákna",
    "Error fetching upcoming events" : "Chyba pri načítavaní nadchádzajúcich udalostí",
    "Error fetching upcoming reminders" : "Chyba pri načítavaní nadchádzajúcich pripomienok",
    "An error occurred while accepting an invitation" : "Pri potvrdzovaní pozvánky sa vyskytla chyba",
    "An error occurred while rejecting an invitation" : "Pri odmietnutí pozvánky sa vyskytla chyba",
    "{guest} (guest)" : "{guest} (návštevník)",
    "Poll draft has been saved" : "Návrh ankety bol uložený",
    "An error occurred while saving the draft" : "Došlo k chybe pri ukladaní konceptu",
    "An error occurred while submitting your vote" : "Pri odosielaní vašeho hlasu nastala chyba",
    "An error occurred while ending the poll" : "Pri ukončovaní ankety nastala chyba",
    "An error occurred while deleting the poll draft" : "Došlo k chybe pri odstraňovaní návrhu ankety",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Anketu „{name}“ vytvoril {user}. Kliknite pre hlasovanie",
    "Failed to add reaction" : "Nepodarilo sa pridať reakciu",
    "Failed to remove reaction" : "Nepodarilo sa odstrániť reakciu",
    "The server is in maintenance mode." : "Server je v režime údržby.",
    "Federated server was updated." : "Združený server bol aktualizovaný.",
    "Error while uploading file \"{fileName}\"" : "Chyba pri nahrávaní súboru \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Nie je voľné miesto pre nahranie súboru \"{fileName}\"",
    "You are not allowed to share files" : "Nemôžete sprístupniť súbory",
    "Error while sharing file" : "Pri zdieľaní súboru došlo k chybe",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Prehliadač, ktorý používate, nie je službou Nextcloud Talk /Rozhovor/ plne podporovaný. Použite najnovšiu verziu prehliadača Mozilla Firefox, Microsoft Edge, Google Chrome alebo Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["O %n hodinu","O %n hodiny","O %n hodín","O %n hodín"],
    "_%n minute _::_%n minutes_" : ["%n minúta","%n minúty","%n minút","%n minút"],
    "In {hours} and {minutes}" : "O {hours} a {minutes}",
    "_In %n minute_::_In %n minutes_" : ["O %n minútu","O %n minúty","O %n minút","O %n minút"],
    "Later today – {timeLocale}" : "Neskôr dnes - {timeLocale}",
    "Set time for later today" : "Nastaviť čas na neskôr dnes",
    "Tomorrow – {timeLocale}" : "Zajtra – {timeLocale}",
    "Set time for tomorrow" : "Nastaviť čas na zajtra",
    "This weekend – {timeLocale}" : "Tento víkend – {timeLocale}",
    "Set time for this weekend" : "Nastavte čas na tento víkend",
    "Next week – {timeLocale}" : "Budúci týždeň – {timeLocale}",
    "Set time for next week" : "Nastaviť čas na budúci týždeň",
    "Message link copied to clipboard" : "Odkaz na správu bol skopírovaný do schránky.",
    "Conversation link copied to clipboard" : "Odkaz na konverzáciu bol skopírovaný do schránky",
    "The link could not be copied" : "Odkaz sa nepodarilo skopírovať.",
    "Error while parsing a PROPFIND error" : "Chyba pri parsovaní chyby PROPFIND",
    "Sending signaling message has failed" : "Odoslanie signalizačnej správy zlyhalo",
    "Lost connection to signaling server. Trying to reconnect." : "Stratené pripojenie k signalizačnému serveru. Pokúšam sa znova pripojiť.",
    "Lost connection to signaling server." : "Stratené pripojenie k signalizačnému serveru.",
    "Connecting is taking longer than expected …" : "Pripojenie trvá dlhšie, než sa očakávalo…",
    "Failed to connect. Retrying …" : "Nepodarilo sa pripojiť. Skúšam znova…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Nepodarilo sa pripojiť. Signálny server môže byť nesprávne nastavený.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Nakonfigurovaný signalizačný server je potrebné aktualizovať, aby bol kompatibilný s touto verziou Talk /Rozhovor/. Kontaktujte svojho správcu.",
    "Please restart the app." : "Prosím, reštartujte aplikáciu.",
    "Please reload the page." : "Obnovte prosím stránku.",
    "Please try to restart the app." : "Skúste prosím reštartovať aplikáciu.",
    "Please try to reload the page." : "Skúste znovu načítať stránku.",
    "Do not disturb" : "Nerušiť",
    "Away" : "Preč",
    "Microphone {number}" : "Mikrofón {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Reproduktor {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Zdá sa, že hovoríte, zatiaľ čo máte stlmené, zrušte ho, aby vás ostatní počuli",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nepodarilo sa nadviazať spojenie aspoň s jedným účastníkom. Pre váš scenár môže byť potrebný server TURN. Požiadajte svojho administrátora, o nastavenie nejakého podľa {linkstart}tejto dokumentácie{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Trvá to dlhšie, ako sa očakávalo. Povolili ste prístup k médiám (alebo nie)? Ak áno, reštartujte prehliadač, pretože zvuk a video zlyhávajú",
    "Access to microphone & camera is only possible with HTTPS" : "Prístup ku mikrofónu a kamere je možný iba použitím HTTPS",
    "Please move your setup to HTTPS" : "Prosím, prejdite na používanie HTTPS",
    "Access to microphone & camera was denied" : "Prístup ku mikrofónu a kamere bol zamietnutý",
    "WebRTC is not supported in your browser" : "WebRTC nie je podporované vaším prehliadačom",
    "Please use a different browser like Firefox or Chrome" : "Použite prosím iný prehliadač, napríklad Firefox alebo Chrome",
    "Error while accessing microphone & camera" : "Nastala chyba pri prístupe ku mikrofónu a kamere",
    "%s Talk on your mobile devices" : "%s Rozhovor na Vašich mobilných zariadeniach",
    "Join conversations at any time, anywhere, on any device." : "Pripojte sa ku konverzáciám kedykoľvek a kdekoľvek na akomkoľvek zariadení.",
    "Android app" : "Android apka",
    "iOS app" : "iOS apka",
    "__language_name__" : "Slovenčina",
    "Webhook Demo" : "Demo Webhooku",
    "Call summary (%s)" : "Zhrnutie hovoru (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Bot so súhrnom hovorov uverejní po hovore súhrnnú správu so zoznamom všetkých účastníkov a načrtnutím úloh",
    "Tasks" : "Úlohy",
    "Notes" : "Poznámky",
    "Reports" : "Zostavy",
    "Decisions" : "Rozhodnutia",
    "Agenda" : "Agenda",
    "Call summary" : "Zhrnutie hovoru",
    "Call summary - {title}" : "Zhrnutie hovoru - {title}",
    "Talk conversation for event" : "Konverzácia Talk pre udalosť",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push je nainštalovaný, čím sa zlepšuje výkon desktopových klientov.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nie je nainštalovaný, čo môže viesť k problémom s výkonom pri používaní desktopových klientov.",
    "Next meeting" : "Ďalšie stretnutie",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Naplánujte stretnutie z vášho kalendára. Na zobrazenie tu je potrebné nastaviť konverzáciu Talk ako miesto",
    "Join conversations from remote Nextcloud servers" : "Pripojte sa k rozhovorom zo vzdialených serverov Nextcloud",
    "Your default media state has been saved" : "Vaše predvolené nastavenie médií bolo uložené.",
    "Set reminder for later today" : "Nastaviť pripomienku na dnes-neskôr.",
    "Set reminder for tomorrow" : "Nastaviť pripomienku na zajtra",
    "Set reminder for this weekend" : "Nastaviť pripomienku na tento víkend",
    "Set reminder for next week" : "Nastaviť pripomienku na budúci týždeň",
    "Generate summary" : "Vygenerovať zhrnutie",
    "Open poll • You voted already" : "Otvorená anketa • Už ste hlasovali",
    "Open poll • Click to vote" : "Otvorená anketa • Kliknite pre hlasovanie",
    "Poll • Ended" : "Anketa ・ Ukončená",
    "Talk recording from {time} ({conversation})" : "Nahrávanie hovoru z {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Výsledky ankety • %n hlas","Výsledky ankety • %n hlasy","Výsledky ankety • %n hlasov","Výsledky ankety • %n hlasy"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Otvorená anketa • %n hlas","Otvorená anketa • %n hlasy","Otvorená anketa • %n hlasov","Otvorená anketa • %n hlasov"],
    "Submit vote" : "Odoslať hlas",
    "Your privacy setting has been saved" : "Vaša nastavenie ochrany osobných údajov bolo uložené",
    "Your personal setting has been saved" : "Vaše osobné nastavenia boli uložené.",
    "Failed to save sounds setting" : "Nepodarilo sa uložiť nastavenie zvukov",
    "Sounds setting saved" : "Nastavenie zvukov uložené",
    "Always shown if recording consent is required" : "Vždy zobrazené, ak je potrebný súhlas na nahrávanie",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk bol aktualizovaný, nemôžete začať alebo pripojiť hovor.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Pripojili ste sa k rozhovoru v inom okne alebo zariadení. Nextcloud Talk /Rozhovor/ v súčasnosti túto možnosť nepodporuje, preto bolo sedenie ukončené.",
    "Nextcloud Talk was updated." : "Nextcloud Talk bol aktualizovaný.",
    "Nextcloud is in maintenance mode." : "Nextcloud je v režime údržby.",
    "Nextcloud Talk Federation was updated." : "Federácia Nextcloud Talk bola aktualizovaná.",
    "Enable live translation" : "Povoliť živý preklad",
    "I picked list style" : "Vybral/a som si štýl zoznamu",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Ahoj! Používaš Talk v zoznamovom štýle alebo s bublinami správ?"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
